<?php
// helper.php

/**
 * Validiert und bereinigt Benutzereingaben.
 *
 * @param string $data Die zu validierende Eingabe
 * @return string Die bereinigte Eingabe
 */
function validateInput($data)
{
    return htmlspecialchars(trim($data));
}

/**
 * Überprüft, ob ein bestimmtes Modul in der aktuellen Lizenz aktiviert ist.
 *
 * @param string $moduleName Der Name des Moduls, z.B. "lagerplatz_modul"
 * @return bool True, wenn das Modul aktiviert ist, sonst False
 */
function isModuleEnabled($moduleName) {
    if (!isset($_SESSION['license_status']) || !$_SESSION['license_status']) {
        return false;
    }

    // Lizenzdaten aus den Einstellungen abrufen
    global $pdo; // Stellen Sie sicher, dass $pdo global verfügbar ist
    $stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "license_data"');
    $stmt->execute();
    $licenseDataJson = $stmt->fetchColumn();

    if (!$licenseDataJson) {
        return false;
    }

    $licenseData = json_decode($licenseDataJson, true);
    if (json_last_error() !== JSON_ERROR_NONE || !is_array($licenseData)) {
        return false;
    }

    // Prüfen, ob das Modul in der Lizenz aktiviert ist
    return in_array($moduleName, $licenseData['modules'] ?? []);
}
?>
