<?php
// install.php

// Aktivieren der Fehleranzeige (nur für Entwicklungszwecke)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Starten der Sitzung
session_start();

// Überprüfen, ob die Installationsseite bereits besucht wurde
if (file_exists('install.lock')) {
    die("<!DOCTYPE html>
    <html lang='de'>
    <head>
        <meta charset='UTF-8'>
        <title>Installation bereits abgeschlossen</title>
        <link href='https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css' rel='stylesheet'>
    </head>
    <body>
    <div class='container my-5'>
        <div class='alert alert-warning' role='alert'>
            Die Installation wurde bereits abgeschlossen. Um die Installation erneut durchzuführen, löschen Sie bitte die Datei <code>install.lock</code> im Installationsverzeichnis.
        </div>
        <a href='index.php' class='btn btn-primary'>Zurück zur Hauptseite</a>
    </div>
    </body>
    </html>");
}

// Verbindung zur Datenbank herstellen
require_once '../db_connect.php'; // Stellen Sie sicher, dass der Pfad korrekt ist

// Funktion zur Ausgabe von Statusmeldungen
function displayStatus($message, $type = 'info') {
    echo "<div class='alert alert-$type' role='alert'>$message</div>";
}

// Funktion zur Überprüfung, ob eine Tabelle existiert
function tableExists($pdo, $tableName) {
    try {
        $result = $pdo->query("SELECT 1 FROM `$tableName` LIMIT 1");
    } catch (Exception $e) {
        return false;
    }
    return $result !== false;
}

// Funktion zur Extraktion von DB-Verbindungsinformationen
function getDatabaseInfo($pdo) {
    try {
        // Datenbankname
        $stmt = $pdo->query('SELECT DATABASE()');
        $dbName = $stmt->fetchColumn();

        // Benutzer
        $stmt = $pdo->query("SELECT USER()");
        $dbUser = $stmt->fetchColumn();

        // Host
        $dsn = $pdo->getAttribute(PDO::ATTR_CONNECTION_STATUS);
        // Der genaue Host ist schwer aus PDO zu extrahieren, daher zeigen wir die DSN an
        return [
            'host' => htmlspecialchars($dsn),
            'database' => htmlspecialchars($dbName),
            'user' => htmlspecialchars($dbUser)
        ];
    } catch (Exception $e) {
        return [
            'host' => 'Unbekannt',
            'database' => 'Unbekannt',
            'user' => 'Unbekannt'
        ];
    }
}

// HTML-Kopf
echo "<!DOCTYPE html>
<html lang='de'>
<head>
    <meta charset='UTF-8'>
    <title>Installationsskript</title>
    <meta name='viewport' content='width=device-width, initial-scale=1.0'>
    <!-- Bootstrap CSS für Styling -->
    <link href='https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css' rel='stylesheet'>
    <style>
        body {
            background-color: #f8f9fa;
        }
        .container {
            max-width: 800px;
        }
        h1 {
            margin-bottom: 20px;
        }
        .db-info {
            background-color: #e9ecef;
            padding: 15px;
            border-radius: 5px;
            margin-bottom: 20px;
        }
    </style>
</head>
<body>
<div class='container my-5'>
    <h1 class='text-center'>Willkommen zum Installationsmodul</h1>
    <p class='lead'>Dieses Modul erstellt alle erforderlichen Datenbanktabellen für das Lagerverwaltungssystem.</p>
    
    <h3>Datenbankverbindung</h3>
    <div class='db-info'>";

    // Datenbankinformationen anzeigen
    $dbInfo = getDatabaseInfo($pdo);
    echo "
        <p><strong>Host:</strong> {$dbInfo['host']}</p>
        <p><strong>Datenbank:</strong> {$dbInfo['database']}</p>
        <p><strong>Benutzer:</strong> {$dbInfo['user']}</p>
    </div>
    
    <p>Bitte stellen Sie sicher, dass die oben genannten Informationen korrekt sind, bevor Sie mit der Installation fortfahren.</p>";

    // Überprüfen, ob das Installationsformular abgesendet wurde
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['install'])) {
        try {
            // Beginnen einer Transaktion
            $pdo->beginTransaction();

            // SQL-Anweisungen zur Erstellung der Tabellen
            $sqlStatements = [

                // Tabelle: lagerplaetze
                "CREATE TABLE IF NOT EXISTS `lagerplaetze` (
                    `id` INT AUTO_INCREMENT PRIMARY KEY,
                    `name` VARCHAR(255) NOT NULL UNIQUE,
                    `kapazitaet` INT NOT NULL DEFAULT 0,
                    `belegung` INT NOT NULL DEFAULT 0,
                    `beschreibung` TEXT NULL,
                    `erstellt_am` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP
                ) ENGINE=InnoDB;",

                // Tabelle: artikel
                "CREATE TABLE IF NOT EXISTS `artikel` (
                    `id` INT AUTO_INCREMENT PRIMARY KEY,
                    `name` VARCHAR(255) NOT NULL,
                    `sku` VARCHAR(100) NOT NULL UNIQUE,
                    `lagerplatz_id` INT NULL,
                    `price` DECIMAL(10,2) NOT NULL,
                    `einheit` VARCHAR(50) NOT NULL,
                    `einheit_faktor` INT NOT NULL DEFAULT 1,
                    `erstellt_am` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
                    `quantity` INT NOT NULL DEFAULT 0,
                    `description` TEXT NULL,
                    FOREIGN KEY (`lagerplatz_id`) REFERENCES `lagerplaetze`(`id`) ON DELETE SET NULL ON UPDATE CASCADE
                ) ENGINE=InnoDB;",

                // Tabelle: artikel_lagerplatz
                "CREATE TABLE IF NOT EXISTS `artikel_lagerplatz` (
                    `id` INT AUTO_INCREMENT PRIMARY KEY,
                    `artikel_id` INT NOT NULL,
                    `lagerplatz_id` INT NOT NULL,
                    `menge` INT NOT NULL DEFAULT 0,
                    UNIQUE KEY `unique_artikel_lagerplatz` (`artikel_id`, `lagerplatz_id`),
                    FOREIGN KEY (`artikel_id`) REFERENCES `artikel`(`id`) ON DELETE CASCADE ON UPDATE CASCADE,
                    FOREIGN KEY (`lagerplatz_id`) REFERENCES `lagerplaetze`(`id`) ON DELETE CASCADE ON UPDATE CASCADE
                ) ENGINE=InnoDB;",

                // Tabelle: eb_entries
                "CREATE TABLE IF NOT EXISTS `eb_entries` (
                    `id` INT AUTO_INCREMENT PRIMARY KEY,
                    `eb_nummer` VARCHAR(20) NOT NULL UNIQUE,
                    `artikel_id` INT NOT NULL,
                    `menge_gesamt` INT NOT NULL DEFAULT 0,
                    `menge_offen` INT NOT NULL DEFAULT 0,
                    `status` ENUM('OFFEN', 'ABGESCHLOSSEN') NOT NULL DEFAULT 'OFFEN',
                    `einheit` VARCHAR(50) NOT NULL,
                    `einheit_faktor` INT NOT NULL DEFAULT 1,
                    FOREIGN KEY (`artikel_id`) REFERENCES `artikel`(`id`) ON DELETE CASCADE ON UPDATE CASCADE
                ) ENGINE=InnoDB;",

                // Tabelle: eb_liste
                "CREATE TABLE IF NOT EXISTS `eb_liste` (
                    `id` INT AUTO_INCREMENT PRIMARY KEY,
                    `eb_nummer` VARCHAR(20) NOT NULL UNIQUE,
                    `artikel_id` INT NOT NULL,
                    `menge_gesamt` INT NOT NULL DEFAULT 0,
                    `menge_offen` INT NOT NULL DEFAULT 0,
                    `status` ENUM('OFFEN', 'ABGESCHLOSSEN') NOT NULL DEFAULT 'OFFEN',
                    `erstellt_am` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
                    `einheit` VARCHAR(50) NOT NULL,
                    `einheit_faktor` INT NOT NULL DEFAULT 1,
                    FOREIGN KEY (`artikel_id`) REFERENCES `artikel`(`id`) ON DELETE CASCADE ON UPDATE CASCADE
                ) ENGINE=InnoDB;",

                // Tabelle: lagerbewegungen
                "CREATE TABLE IF NOT EXISTS `lagerbewegungen` (
                    `id` INT AUTO_INCREMENT PRIMARY KEY,
                    `artikel_id` INT NOT NULL,
                    `lagerplatz_id` INT NOT NULL,
                    `menge` INT NOT NULL,
                    `bewegungstyp` ENUM('EINGANG', 'AUSGANG') NOT NULL,
                    `datum` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
                    `bemerkungen` TEXT NULL,
                    FOREIGN KEY (`artikel_id`) REFERENCES `artikel`(`id`) ON DELETE CASCADE ON UPDATE CASCADE,
                    FOREIGN KEY (`lagerplatz_id`) REFERENCES `lagerplaetze`(`id`) ON DELETE CASCADE ON UPDATE CASCADE
                ) ENGINE=InnoDB;"
            ];

            try {
                foreach ($sqlStatements as $sql) {
                    $pdo->exec($sql);
                }

                file_put_contents('install.lock', 'Installation abgeschlossen am ' . date('Y-m-d H:i:s'));

                displayStatus("Alle Tabellen wurden erfolgreich erstellt.", "success");
                echo "<a href='index.php' class='btn btn-primary mt-3'>Zurück zur Hauptseite</a>";

            } catch (PDOException $e) {
                displayStatus("Fehler bei der Installation: " . htmlspecialchars($e->getMessage()), "danger");
                echo "<a href='install.php' class='btn btn-secondary mt-3'>Zurück zur Installation</a>";
            }


        } catch (PDOException $e) {

            /* Nur wenn wirklich eine aktive Transaktion besteht, führen wir einen Rollback aus.
               So wird die Fehlermeldung "There is no active transaction" verhindert. */
            if ($pdo->inTransaction()) {
                $pdo->rollBack();
            }

            displayStatus("Fehler bei der Installation: " . htmlspecialchars($e->getMessage()), "danger");
            echo "<a href='install.php' class='btn btn-secondary mt-3'>Zurück zur Installation</a>";
        }
    } else {
        // Anzeige des Installationsformulars
        echo "
        <form method='POST' action=''>
            <button type='submit' name='install' class='btn btn-danger'>Installation starten</button>
        </form>";
    }

    // HTML-Fuß
    echo "</div>
    <!-- Bootstrap JS für Funktionalitäten -->
    <script src='https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js'></script>
    </body>
    </html>";
?>
