<?php
session_start();
include '../db_connect.php';
require_once 'helper.php';

$eb_nummer = $_GET['eb_nummer'] ?? '';
$eb_entry = getEBByNummer($eb_nummer);

if (!$eb_entry) {
    $_SESSION['error'] = "EB-Eintrag nicht gefunden!";
    header('Location: index.php?action=eb_list');
    exit();
}

$message = $_SESSION['message'] ?? null;
$error = $_SESSION['error'] ?? null;
unset($_SESSION['message'], $_SESSION['error']);
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Wareneingang Prozess</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link 
        href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" 
        rel="stylesheet"
    >
</head>
<body>
<?php include 'partials/navbar.php'; ?>
<div class="container my-5">
    <h1 class="text-center text-primary">Wareneingang buchen für <?= htmlspecialchars($eb_nummer); ?></h1>
    <?php if ($message): ?>
        <div class="alert alert-success text-center"><?= htmlspecialchars($message); ?></div>
    <?php endif; ?>
    <?php if ($error): ?>
        <div class="alert alert-danger text-center"><?= htmlspecialchars($error); ?></div>
    <?php endif; ?>

    <p>Artikel: <?= htmlspecialchars($eb_entry['name'] . " (SKU: " . $eb_entry['sku'] . ")"); ?></p>
    <p>Gesamtmenge erwartet: <?= (int)$eb_entry['menge_gesamt']; ?></p>
    <p>Offen: <?= (int)$eb_entry['menge_offen']; ?></p>
    <p>Status: <?= htmlspecialchars($eb_entry['status']); ?></p>

    <?php if ($eb_entry['menge_offen'] > 0): ?>
        <form action="index.php?action=wareneingang_buchen" method="post" class="mt-4">
            <input type="hidden" name="eb_nummer" value="<?= htmlspecialchars($eb_nummer); ?>">
            <div class="mb-3">
                <label class="form-label">Gelieferte Menge</label>
                <input type="number" name="gelieferte_menge" class="form-control" min="1" max="<?= (int)$eb_entry['menge_offen']; ?>" required>
            </div>
            <div class="mb-3">
                <label class="form-label">Art der Lieferung</label>
                <select name="liefer_art" class="form-select" required>
                    <option value="TEIL">TEIL</option>
                    <option value="VOLL">VOLL</option>
                </select>
            </div>
            <div class="d-flex justify-content-between mt-4">
                <a href="index.php?action=eb_list" class="btn btn-secondary">Zurück</a>
                <button type="submit" class="btn btn-success">Buchen</button>
            </div>
        </form>
    <?php else: ?>
        <p class="text-success text-center">Dieser Wareneingang ist bereits vollständig abgeschlossen.</p>
    <?php endif; ?>
</div>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
