<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

$moduleInstalled = file_exists(__DIR__ . '/MODUL/install.lock');

// Überprüfung, ob das Formular zum Aktualisieren der Belegung abgesendet wurde
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['updateBelegung'])) {
    // Sicherheitsüberprüfung der empfangenen Daten
    $belegungen = $_POST['belegung'];
    foreach ($belegungen as $lagerplatzId => $belegung) {
        $lagerplatzId = (int)$lagerplatzId;
        $belegung = (int)$belegung;

        // Optional: Validierung, ob die Belegung innerhalb der Kapazität liegt
        $stmt = $pdo->prepare('SELECT kapazitaet FROM lagerplaetze WHERE id = ?');
        $stmt->execute([$lagerplatzId]);
        $kapazitaet = $stmt->fetchColumn();

        if ($belegung >= 0 && $belegung <= $kapazitaet) {
            // Aktualisierung der Belegung in der Datenbank
            $stmt = $pdo->prepare('UPDATE lagerplaetze SET belegung = ? WHERE id = ?');
            $stmt->execute([$belegung, $lagerplatzId]);
        } else {
            // Fehlermeldung hinzufügen, wenn Belegung außerhalb der Kapazität liegt
            $errors[] = "Die Belegung für Lagerplatz ID {$lagerplatzId} liegt außerhalb der Kapazität.";
        }
    }

    if (empty($errors)) {
        // Erfolgsmeldung anzeigen
        $message = "Die tatsächliche Belegung wurde erfolgreich aktualisiert.";
    }
}

// Aufgaben abrufen (nur "offen" und "in_bearbeitung")
$stmt = $pdo->query("SELECT * FROM aufgaben WHERE status IN ('offen', 'in_bearbeitung') ORDER BY erstellt_am DESC");
$aufgaben = $stmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Aufgaben</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Eigenes CSS -->
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f8f9fa;
            padding-bottom: 60px; /* Platz für die mobile Navigation */
        }

        /* Hauptcontainer */
        .container {
            margin-top: 20px;
        }

        /* Aufgabenliste */
        .list-group-item {
            background-color: #fff;
            border: 1px solid #dee2e6;
            margin-bottom: 15px;
            border-radius: 8px;
            padding: 20px;
        }

        .list-group-item h5 {
            font-weight: bold;
            margin-bottom: 10px;
        }

        .list-group-item p {
            margin-bottom: 15px;
        }

        /* Buttons */
        .btn-custom {
            margin-right: 10px;
        }

        /* Meldungsstil */
        .message, .error {
            margin-top: 20px;
            padding: 15px;
            border-radius: 5px;
        }

        /* Navbar Styling */
        .navbar {
            height: 86px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: background-color 0.5s, box-shadow 0.5s;
        }

        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            height: 66px;
        }

        .navbar-brand img {
            height: 100%; /* Höhe des Logos auf die Höhe der Navbar setzen */
            width: auto; /* Proportionen beibehalten */
            object-fit: contain; /* Falls nötig, das Logo anpassen */
        }

        .message {
            border: 1px solid #28a745;
            background-color: #d4edda;
            color: #155724;
        }

        .error {
            border: 1px solid #dc3545;
            background-color: #f8d7da;
            color: #721c24;
        }

        /* Druckansicht */
        @media print {
            body * { visibility: hidden; }
            #printable-area, #printable-area * { visibility: visible; }
            #printable-area { position: absolute; top: 0; left: 0; width: 100%; }
            #print-button { display: none; }
        }

        /* Tabelle in der Druckansicht */
        #printable-area table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }

        #printable-area th, #printable-area td {
            border: 1px solid #000;
            padding: 8px;
            text-align: left;
        }

        #printable-area th {
            background-color: #f2f2f2;
        }

        /* Mobile Bottom Navigation */
        .mobile-nav {
            display: none;
        }
        @media (max-width: 767.98px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #343a40;
                border-top: 1px solid #495057;
                justify-content: space-around;
                padding: 10px 0;
                z-index: 1000;
            }
            .mobile-nav a {
                color: #adb5bd;
                text-decoration: none;
                font-size: 0.85em;
                text-align: center;
                flex: 1;
                display: flex;
                flex-direction: column;
                align-items: center;
            }
            .mobile-nav a i {
                font-size: 1.5em;
                margin-bottom: 2px;
            }
            .mobile-nav a.active {
                color: #ffffff;
            }
        }

        /* Verhindert Flackern durch setTimeout */
        canvas {
            opacity: 1;
            transition: opacity 0.5s;
        }
    </style>
</head>
<body>

<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png" alt="Logo"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-2"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-2"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-2"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-2"></i>Berichte
             </a>
         </li>
         <?php if ($moduleInstalled): ?>
             <li class="nav-item">
                 <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
                     <i class="bi bi-box me-2"></i>Artikel
                 </a>
             </li>
         <?php endif; ?>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill me-2"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-2"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>


<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <?php if ($moduleInstalled): ?>
        <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
            <i class="bi bi-box"></i>
            Artikel
        </a>
    <?php endif; ?>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="container">
    <h2 class="mb-4"><i class="bi bi-list-task"></i> Aufgaben</h2>

    <!-- Erfolgsmeldung -->
    <?php if (isset($message)): ?>
        <div class="message">
            <i class="bi bi-check-circle-fill"></i> <?php echo htmlspecialchars($message); ?>
        </div>
    <?php endif; ?>

    <!-- Fehlermeldungen -->
    <?php if (!empty($errors)): ?>
        <div class="error">
            <i class="bi bi-exclamation-triangle-fill"></i>
            <?php foreach ($errors as $error): ?>
                <p><?php echo htmlspecialchars($error); ?></p>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>

    <!-- Buttons zu den Modulen -->
    <div class="mb-4">
        <a href="inventur.php" class="btn btn-primary btn-custom">
            <i class="bi bi-clipboard-data"></i> Inventur durchführen
        </a>
        <a href="kapazitaet.php" class="btn btn-secondary btn-custom">
            <i class="bi bi-boxes"></i> Kapazität festlegen
        </a>
    </div>

    <!-- Aufgabenliste -->
    <div class="list-group">
        <?php if (!empty($aufgaben)): ?>
            <?php foreach ($aufgaben as $aufgabe): ?>
                <div class="list-group-item">
                    <h5><i class="bi bi-calendar-event"></i> <?php echo htmlspecialchars(date('d.m.Y', strtotime($aufgabe['datum']))); ?></h5>
                    <p><?php echo nl2br(htmlspecialchars($aufgabe['inhalt'])); ?></p>

                    <?php if ($aufgabe['status'] === 'offen'): ?>
                        <form method="POST" action="start_inventur.php" class="d-inline">
                            <input type="hidden" name="aufgabe_id" value="<?php echo $aufgabe['id']; ?>">
                            <button type="submit" name="startInventur" class="btn btn-success">
                                <i class="bi bi-play-circle"></i> Inventur starten
                            </button>
                        </form>
                    <?php elseif ($aufgabe['status'] === 'in_bearbeitung'): ?>
                        <button class="btn btn-warning" disabled>
                            <i class="bi bi-hourglass-split"></i> Wird bearbeitet
                        </button>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        <?php else: ?>
            <p class="text-muted">Keine Aufgaben vorhanden.</p>
        <?php endif; ?>
    </div>



    <!-- Bereich für die Druckansicht markieren -->
    <div id="printable-area" style="display:none;">
        <h3 class="mt-5"><i class="bi bi-warehouse"></i> Lagerplatzliste</h3>
        <form method="POST" action="aufgaben.php">
            <table class="table table-bordered mt-3">
                <thead class="table-dark">
                    <tr>
                        <th>ID</th>
                        <th>Name</th>
                        <th>Standort</th>
                        <th>Kapazität</th>
                        <th>Aktuelle Belegung</th>
                        <th>Tatsächliche Belegung</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    // Abfrage der Lagerplätze
                    $stmt = $pdo->query('SELECT id, name, standort, kapazitaet, belegung FROM lagerplaetze');
                    $lagerplaetze = $stmt->fetchAll();

                    foreach ($lagerplaetze as $lagerplatz):
                    ?>
                    <tr>
                        <td><?php echo htmlspecialchars($lagerplatz['id']); ?></td>
                        <td><?php echo htmlspecialchars($lagerplatz['name']); ?></td>
                        <td><?php echo htmlspecialchars($lagerplatz['standort']); ?></td>
                        <td><?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?></td>
                        <td><?php echo htmlspecialchars($lagerplatz['belegung']); ?></td>
                        <td>
                            <input type="number" name="belegung[<?php echo $lagerplatz['id']; ?>]" value="" min="0" max="<?php echo htmlspecialchars($lagerplatz['kapazitaet']); ?>" required class="form-control">
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
            <!-- Druck-Button und Speichern-Button -->
            <div class="mt-3">
                <button type="submit" name="updateBelegung" class="btn btn-success">
                    <i class="bi bi-save"></i> Tatsächliche Belegung speichern
                </button>
                <button id="print-button" type="button" onclick="printContent();" class="btn btn-primary">
                    <i class="bi bi-printer"></i> Drucken
                </button>
            </div>
        </form>
    </div>
</div>

<!-- Bootstrap JS und Abhängigkeiten -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<script>
function showLagerplatzListe() {
    document.getElementById('printable-area').style.display = 'block';
    // Scrollen zum Bereich
    document.getElementById('printable-area').scrollIntoView({ behavior: 'smooth' });
}

function printContent() {
    window.print();
}
</script>

</body>
</html>
