<?php
include 'db_connect.php';

// Aktuelles Datum
$datum = date('Y-m-d');

// **1. Automatische Bereinigung veralteter Daten**
// Löschen von Inventurprotokollen, die älter als ein Jahr sind
$cleanupStmt = $pdo->prepare('DELETE FROM inventur_protokoll WHERE datum < DATE_SUB(NOW(), INTERVAL 1 YEAR)');
$cleanupStmt->execute();

// Logging für Bereinigung
$bereinigteDaten = $cleanupStmt->rowCount();
echo "Bereinigung abgeschlossen: $bereinigteDaten alte Protokolle gelöscht.\n";

// **2. Automatische Erstellung regelmäßiger Berichte**
// Verzeichnis für Berichte
$reportsDirectory = __DIR__ . '/berichte';

// Verzeichnis erstellen, falls nicht vorhanden
if (!is_dir($reportsDirectory)) {
    mkdir($reportsDirectory, 0777, true);
}

// Bericht erstellen
$reportFile = $reportsDirectory . '/bericht_' . $datum . '.txt';
$reportContent = "Lagerbericht - Datum: $datum\n\n";

// Dynamik der Lagerplätze berechnen
$query = "
    SELECT lagerplatz_id, 
           COUNT(*) AS wechsel, 
           MAX(datum) AS letzte_bewegung 
    FROM inventur_protokoll 
    GROUP BY lagerplatz_id
    ORDER BY wechsel DESC
";

$result = $pdo->query($query)->fetchAll();

// Berichtinhalte sammeln
if (empty($result)) {
    $reportContent .= "Keine Daten verfügbar für die Lagerplatzdynamik.\n";
} else {
    $reportContent .= "Lagerplatz-ID | Wechsel | Letzte Bewegung\n";
    $reportContent .= str_repeat('-', 40) . "\n";

    foreach ($result as $row) {
        $lagerplatz_id = $row['lagerplatz_id'];
        $wechsel = $row['wechsel'];
        $letzte_bewegung = $row['letzte_bewegung'];

        $reportContent .= sprintf("%-14s | %-6d | %s\n", $lagerplatz_id, $wechsel, $letzte_bewegung ?? 'Keine');
    }
}

// Bericht speichern
file_put_contents($reportFile, $reportContent);

// Logging für Bericht
echo "Bericht gespeichert: $reportFile\n";

// Aufgabe für die wöchentliche Inventur erstellen
$inhalt = "Die wöchentliche Inventur ist fällig. Bitte überprüfen Sie die Nutzungsdynamik der Lagerplätze.";
$stmt = $pdo->prepare('INSERT INTO aufgaben (datum, inhalt) VALUES (?, ?)');
$stmt->execute([$datum, $inhalt]);

echo "Aufgabe für wöchentliche Inventur hinzugefügt.\n";
?>
