<?php
// Starten Sie die Sitzung, falls nicht bereits gestartet
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// Datenbankverbindung einbinden
include 'db_connect.php';

// Lizenzprüfungsfunktion
function verifyLicenseWithServer($licenseKey) {
    $url = 'https://smp-solution.com/license_api.php?action=verify';

    $postData = [
        'license_key' => $licenseKey
    ];

    $ch = curl_init($url);

    curl_setopt_array($ch, [
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_POST => true,
        CURLOPT_POSTFIELDS => http_build_query($postData),
        CURLOPT_TIMEOUT => 10,
        CURLOPT_SSL_VERIFYPEER => true,
    ]);

    $result = curl_exec($ch);

    if (curl_errno($ch)) {
        $error_msg = curl_error($ch);
        file_put_contents('curl_error_log.txt', date('[Y-m-d H:i:s] ') . "cURL Fehler: $error_msg\n", FILE_APPEND);
        curl_close($ch);
        return false;
    }

    $http_status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($http_status !== 200) {
        return false;
    }

    $response = json_decode($result, true);

    if (json_last_error() !== JSON_ERROR_NONE) {
        $jsonError = json_last_error_msg();
        file_put_contents('curl_error_log.txt', date('[Y-m-d H:i:s] ') . "JSON Fehler: $jsonError\n", FILE_APPEND);
        return false;
    }

    return $response;
}

// Lizenzprüfung durchführen
$licenseKey = null;

// Prüfen, ob ein Lizenzschlüssel über das Formular gesendet wurde
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['license_key'])) {
    $licenseKey = trim($_POST['license_key']);

    // Lizenz mit der API überprüfen
    $licenseResponse = verifyLicenseWithServer($licenseKey);

    if ($licenseResponse) {
        if ($licenseResponse['status'] === 'valid') {
            // Lizenz ist gültig, in der Datenbank speichern
            $stmt = $pdo->prepare('REPLACE INTO settings (key_name, value) VALUES ("license_key", ?)');
            $stmt->execute([$licenseKey]);

            $stmt = $pdo->prepare('REPLACE INTO settings (key_name, value) VALUES ("license_data", ?)');
            $stmt->execute([json_encode($licenseResponse['data'])]);

            // Lizenzstatus und Module in der Sitzung speichern
            $_SESSION['license_status'] = true;
            $_SESSION['license_last_check'] = time();
            $_SESSION['license_modules'] = $licenseResponse['data']['modules'] ?? []; // Speichere Module
            $_SESSION['license_key'] = $licenseKey; // Lizenzschlüssel speichern

            // Weiterleitung nach erfolgreicher Prüfung
            header("Location: dashboard.php");
            exit;
        } elseif ($licenseResponse['status'] === 'blocked') {
            // Lizenz ist blockiert, spezifische Fehlermeldung anzeigen
            $_SESSION['license_status'] = false;
            $_SESSION['license_last_check'] = time();

            // Lizenzdaten aus der Datenbank löschen
            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_key"');
            $stmt->execute();

            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_data"');
            $stmt->execute();

            showLicenseForm("Ihre Lizenz ist abgelaufen und wurde gesperrt. Bitte erneuern Sie Ihre Lizenz.");
            exit;
        } else {
            // Lizenz ungültig, allgemeine Fehlermeldung anzeigen
            $_SESSION['license_status'] = false;
            $_SESSION['license_last_check'] = time();

            // Lizenzdaten aus der Datenbank löschen
            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_key"');
            $stmt->execute();

            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_data"');
            $stmt->execute();

            showLicenseForm("Lizenzprüfung fehlgeschlagen oder Lizenz ist ungültig. Bitte geben Sie eine neue Lizenz ein.");
            exit;
        }
    } else {
        // Fehler bei der API-Verbindung oder ungültige Antwort
        $_SESSION['license_status'] = false;
        $_SESSION['license_last_check'] = time();

        showLicenseForm("Es konnte keine Verbindung zur Lizenzprüfung hergestellt werden. Bitte versuchen Sie es später erneut.");
        exit;
    }
}

// Lizenzschlüssel aus der Datenbank abrufen
$stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "license_key"');
$stmt->execute();
$licenseKey = $stmt->fetchColumn();

$currentTime = time();
$cacheLifetime = 3600; // Reduziert auf 1 Stunde für Tests

// Überprüfen, ob die Lizenzprüfung zwischengespeichert wurde
if (!isset($_SESSION['license_status']) || !isset($_SESSION['license_last_check']) ||
    ($currentTime - $_SESSION['license_last_check']) > $cacheLifetime) {
    
    if (!$licenseKey) {
        // Kein Lizenzschlüssel vorhanden, Benutzeraufforderung anzeigen
        showLicenseForm("Kein Lizenzschlüssel gefunden. Bitte geben Sie Ihren Lizenzschlüssel ein.");
        exit;
    }

    // Lizenz mit der API überprüfen
    $licenseResponse = verifyLicenseWithServer($licenseKey);

    if ($licenseResponse) {
        if ($licenseResponse['status'] === 'valid') {
            // Lizenz ist gültig, Status und Module aktualisieren
            $_SESSION['license_status'] = true;
            $_SESSION['license_last_check'] = $currentTime;
            $_SESSION['license_modules'] = $licenseResponse['data']['modules'] ?? []; // Speichere Module
            $_SESSION['license_key'] = $licenseKey; // Lizenzschlüssel speichern
        } elseif ($licenseResponse['status'] === 'blocked') {
            // Lizenz ist blockiert, spezifische Fehlermeldung anzeigen
            $_SESSION['license_status'] = false;
            $_SESSION['license_last_check'] = $currentTime;

            // Lizenzdaten aus der Datenbank löschen
            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_key"');
            $stmt->execute();

            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_data"');
            $stmt->execute();

            showLicenseForm("Ihre Lizenz ist abgelaufen und wurde gesperrt. Bitte erneuern Sie Ihre Lizenz.");
            exit;
        } else {
            // Lizenz ungültig, allgemeine Fehlermeldung anzeigen
            $_SESSION['license_status'] = false;
            $_SESSION['license_last_check'] = $currentTime;

            // Lizenzdaten aus der Datenbank löschen
            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_key"');
            $stmt->execute();

            $stmt = $pdo->prepare('DELETE FROM settings WHERE key_name = "license_data"');
            $stmt->execute();

            showLicenseForm("Lizenzprüfung fehlgeschlagen oder Lizenz ist ungültig. Bitte geben Sie eine neue Lizenz ein.");
            exit;
        }
    } else {
        // Fehler bei der API-Verbindung oder ungültige Antwort
        $_SESSION['license_status'] = false;
        $_SESSION['license_last_check'] = $currentTime;

        showLicenseForm("Es konnte keine Verbindung zur Lizenzprüfung hergestellt werden. Bitte versuchen Sie es später erneut.");
        exit;
    }
}

// Lizenzstatus verwenden
if (!$_SESSION['license_status']) {
    // Lizenz ist nicht gültig oder blockiert
    showLicenseForm("Lizenzprüfung fehlgeschlagen oder Lizenz ist ungültig. Bitte geben Sie eine neue Lizenz ein.");
    exit;
}

// Funktion zum Anzeigen des Lizenzformulars
function showLicenseForm($message) {
    ?>
    <!DOCTYPE html>
    <html lang="de">
    <head>
        <meta charset="UTF-8">
        <title>Lizenzprüfung</title>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
        <style>
            body {
                background-color: #f9f9f9;
                font-family: Arial, sans-serif;
            }
            .container {
                margin-top: 50px;
            }
            .alert {
                margin-bottom: 20px;
            }
            .shop-alert {
                margin-top: 20px;
                background-color: #e8f4ff;
                border: 1px solid #007bff;
                color: #007bff;
                padding: 20px;
                border-radius: 8px;
                text-align: center;
            }
            .shop-alert a {
                color: #0056b3;
                text-decoration: none;
                font-weight: bold;
            }
            .shop-alert a:hover {
                text-decoration: underline;
            }
        </style>
    </head>
    <body>
        <div class="container">
            <h2 class="text-center">Lizenzprüfung</h2>

            <?php if (!empty($message)): ?>
                <div class="alert alert-danger"><?= htmlspecialchars($message) ?></div>
            <?php endif; ?>

            <!-- Lizenzformular -->
            <form method="POST">
                <div class="mb-3">
                    <label for="license_key" class="form-label">Lizenzschlüssel</label>
                    <input type="text" name="license_key" id="license_key" class="form-control" required>
                </div>
                <button type="submit" class="btn btn-primary w-100">Lizenz prüfen</button>
            </form>

            <!-- Hinweis auf den Shop -->
            <div class="shop-alert">
                <p>Sie haben noch keinen Lizenzschlüssel? Erwerben Sie ihn hier <a href="https://smp-solution.com/shop.php#pricing" target="_blank">ZUM SHOP</a></p>
            </div>
        </div>
    </body>
    </html>
    <?php
}
?>
