<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

$moduleInstalled = file_exists(__DIR__ . '/MODUL/install.lock');

$isAdmin = isset($_SESSION['rolle']) && strtolower($_SESSION['rolle']) === 'admin';

// Nachrichtenspeicher
$message = "";

// Lizenzinformationen aus der settings-Tabelle abrufen
$stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "license_data"');
$stmt->execute();
$licenseDataJson = $stmt->fetchColumn();
$licenseData = $licenseDataJson ? json_decode($licenseDataJson, true) : null;

// Berechnung der verbleibenden Tage und Anpassung für LIFETIME
if ($licenseData && isset($licenseData['remaining_days'])) {
    if ($licenseData['remaining_days'] > 3650) { // Anpassung des Schwellwerts auf 10 Jahre
        $licenseData['remaining_days_display'] = 'LIFETIME';
    } else {
        $licenseData['remaining_days_display'] = $licenseData['remaining_days'] . ' Tage';
    }
}

// Laden der aktuellen Einstellungen aus der Datenbank
$stmt = $pdo->prepare('SELECT * FROM settings WHERE key_name = "lagerplatz_ebenen" LIMIT 1');
$stmt->execute();
$setting = $stmt->fetch();
$lagerplatz_ebenen = $setting ? json_decode($setting['value'], true) : [];

// Laden der Produkttyp-Zuordnung
$stmt = $pdo->prepare('SELECT * FROM settings WHERE key_name = "lagerplatz_mapping" LIMIT 1');
$stmt->execute();
$mappingSetting = $stmt->fetch();
$mapping = $mappingSetting ? json_decode($mappingSetting['value'], true) : [];

// Verarbeitung der Formulareingaben
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['ebenen_kurzel']) && isset($_POST['ebenen_bezeichnung'])) {
        $new_ebenen = [];
        foreach ($_POST['ebenen_kurzel'] as $index => $kurzel) {
            $kurzel = trim($kurzel);
            $bezeichnung = trim($_POST['ebenen_bezeichnung'][$index]);
            if (!empty($kurzel) && !empty($bezeichnung)) {
                $new_ebenen[] = ["kurzel" => $kurzel, "bezeichnung" => $bezeichnung];
            }
        }
        $new_ebenen_json = json_encode($new_ebenen);

        if ($setting) {
            // Bestehende Einstellung aktualisieren
            $stmt = $pdo->prepare('UPDATE settings SET value = :value, updated_at = NOW() WHERE key_name = "lagerplatz_ebenen"');
        } else {
            // Neue Einstellung einfügen
            $stmt = $pdo->prepare('INSERT INTO settings (key_name, value, description) VALUES ("lagerplatz_ebenen", :value, "Lagerplatz-Ebenen")');
        }

        $stmt->execute(['value' => $new_ebenen_json]);
        $message = "Die Lagerplatz-Ebenen wurden erfolgreich aktualisiert.";
        $lagerplatz_ebenen = $new_ebenen;
    }

    if (isset($_POST['mapping_keys']) && isset($_POST['mapping_values'])) {
        $new_mapping = [];
        foreach ($_POST['mapping_keys'] as $index => $key) {
            $key = trim($key);
            $value = trim($_POST['mapping_values'][$index]);
            if (!empty($key) && !empty($value)) {
                $new_mapping[$key] = $value;
            }
        }
        $new_mapping_json = json_encode($new_mapping);

        if ($mappingSetting) {
            // Bestehende Einstellung aktualisieren
            $stmt = $pdo->prepare('UPDATE settings SET value = :value, updated_at = NOW() WHERE key_name = "lagerplatz_mapping"');
        } else {
            // Neue Einstellung einfügen
            $stmt = $pdo->prepare('INSERT INTO settings (key_name, value, description) VALUES ("lagerplatz_mapping", :value, "Zuordnung Produkttypen zu Lagerplatz-Ebenen")');
        }

        $stmt->execute(['value' => $new_mapping_json]);
        $message .= "<br>Die Produkttypen-Zuordnung wurde erfolgreich aktualisiert.";
        $mapping = $new_mapping;
    }
}
?>

<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Einstellungen - Lagerplatz</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <style>
        body {
            background-color: #ffffff;
            color: #333333;
        }
        .container-fluid {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }
        /* Lizenz-Card im eleganten dunklen Stil */
        .license-card {
            position: relative;
            background: linear-gradient(to bottom right, #2b2b2b, #1e1e1e);
            border: 1px solid #444;
            border-radius: 15px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.5);
            padding: 20px;
            overflow: hidden;
            color: #d4af37; /* Goldene Schrift */
            transition: all 0.3s ease-in-out;
        }

        .license-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.7);
            background: linear-gradient(to bottom right, #3b3b3b, #2e2e2e);
        }

        .license-card .card-header {
            background-color: transparent;
            border-radius: 10px 10px 0 0;
            padding: 15px;
            display: flex;
            align-items: center;
            justify-content: flex-start;
            font-size: 1.2rem;
            font-weight: bold;
            border-bottom: 1px solid #444;
            color: #d4af37;
            transition: all 0.3s ease-in-out;
        }

        .license-card .card-header i {
            font-size: 2.5rem;
            color: #d4af37;
            transition: transform 0.3s ease-in-out;
        }

        .license-card:hover .card-header i {
            transform: scale(1.1);
        }

        .license-card .card-body {
            padding: 20px;
        }

        .license-card .license-details h6 {
            font-weight: 600;
            font-size: 1rem;
            color: #d4af37;
            margin-bottom: 0;
        }

        .license-card .license-details p {
            font-size: 1rem;
            margin-bottom: 0;
            text-align: right;
            color: #fff; /* Weiß für Kontrast */
        }

        .license-card .badge {
            padding: 5px 10px;
            font-size: 0.9rem;
            border-radius: 5px;
            text-transform: uppercase;
            font-weight: bold;
        }

        .license-card .badge-success {
            background-color: #28a745;
            color: #fff;
        }

        .license-card .badge-danger {
            background-color: #dc3545;
            color: #fff;
        }

        .alert-warning {
            background-color: #443322;
            color: #d4af37;
            border: 1px solid #d4af37;
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 10px;
            margin-top: 10px;
        }

        .alert-warning {
            background-color: #fff3cd;
            color: #856404;
            border: 1px solid #ffeeba;
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 10px;
            margin-top: 10px;
        }
        .dashboard {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin: 0 20px; /* Linken und rechten Rand hinzufügen */
        }
        .dashboard-card {
            background-color: #f8f9fa;
            border: 1px solid #dee2e6;
            border-radius: 10px;
            padding: 20px;
            flex: 1 1 calc(45% - 20px); /* Karten schmaler machen */
            min-width: 300px;
        }
        .dashboard-card h5 {
            margin-bottom: 20px;
            color: #333333;
        }
        .dashboard-card form .input-group, .dashboard-card form .form-group {
            margin-bottom: 15px;
        }
        .dashboard-card .btn {
            border-radius: 5px;
        }
        .navbar {
            background-color: #343a40;
            height: 106px;
            padding-left: 0;
            padding-right: 0;
        }
        .navbar .container-fluid {
            max-width: 100%;
            padding-left: 0;
            padding-right: 0;
        }
        .navbar-brand img {
            height: 66px;
        }
        .alert {
            margin-top: 20px;
        }
        /* Scrollbar anpassen */
        ::-webkit-scrollbar {
            width: 10px;
        }
        ::-webkit-scrollbar-track {
            background: #f1f1f1;
        }
        ::-webkit-scrollbar-thumb {
            background: #888;
            border-radius: 5px;
        }
        ::-webkit-scrollbar-thumb:hover {
            background: #555;
        }
        /* Mobile Anpassungen */
        @media (max-width: 767.98px) {
            .dashboard-card {
                flex: 1 1 100%;
            }
            .navbar-brand {
                font-size: 1.2rem;
            }
            .dashboard {
                margin: 0 10px; /* Ränder auf mobilen Geräten anpassen */
            }
        }
        /* Mobile Bottom Navigation */
        .mobile-nav {
            display: none;
        }
        @media (max-width: 767.98px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #343a40;
                border-top: 1px solid #495057;
                justify-content: space-around;
                padding: 10px 0;
                z-index: 1000;
            }
            .mobile-nav a {
                color: #adb5bd;
                text-decoration: none;
                font-size: 0.85em;
                text-align: center;
                flex: 1;
                display: flex;
                flex-direction: column;
                align-items: center;
            }
            .mobile-nav a i {
                font-size: 1.5em;
                margin-bottom: 2px;
            }
            .mobile-nav a.active {
                color: #ffffff;
            }
        }
        .input-group-text.handle {
            cursor: move;
        }
        .ebene-item.dragging {
            opacity: 0.5;
        }
    </style>
</head>
<body>

<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png" alt="Logo"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-2"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-2"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-2"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-2"></i>Berichte
             </a>
         </li>
         <?php if ($moduleInstalled): ?>
             <li class="nav-item">
                 <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
                     <i class="bi bi-box me-2"></i>Artikel
                 </a>
             </li>
         <?php endif; ?>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill me-2"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-2"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>


<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <?php if ($moduleInstalled): ?>
        <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
            <i class="bi bi-box"></i>
            Artikel
        </a>
    <?php endif; ?>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="container-fluid">
    <?php if (!empty($message)): ?>
        <div class="alert alert-success"><?php echo nl2br(htmlspecialchars($message)); ?></div>
    <?php endif; ?>

    <div class="dashboard">
        <div class="dashboard-card license-card">
            <div class="card-header d-flex align-items-center">
                <i class="bi bi-person-badge-fill me-3"></i>
                <h5 class="mb-0"><font color="white">Lizenzstatus</font></h5>
            </div>
            <div class="card-body">
                <?php if ($licenseData): ?>
                    <div class="license-details">
                        <div class="d-flex justify-content-between align-items-center mb-3">
                            <h6>Kunde:</h6>
                            <p class="mb-0"><strong><?php echo htmlspecialchars($licenseData['customer_name']); ?></strong></p>
                        </div>
                        <div class="d-flex justify-content-between align-items-center mb-3">
                            <h6>Status:</h6>
                            <p class="mb-0">
                                <span class="badge bg-<?php echo ($licenseData['status'] === 'Aktiv') ? 'success' : 'danger'; ?>">
                                    <?php echo htmlspecialchars($licenseData['status']); ?>
                                </span>
                            </p>
                        </div>
                        <div class="d-flex justify-content-between align-items-center mb-3">
                            <h6>Gültig von:</h6>
                            <p class="mb-0"><?php echo htmlspecialchars($licenseData['start_date']); ?></p>
                        </div>
                        <div class="d-flex justify-content-between align-items-center mb-3">
                            <h6>Gültig bis:</h6>
                            <p class="mb-0"><?php echo htmlspecialchars($licenseData['end_date']); ?></p>
                        </div>
                        <div class="d-flex justify-content-between align-items-center">
                            <h6>Verbleibende Tage:</h6>
                            <p class="mb-0 text-<?php echo ($licenseData['remaining_days'] > 0) ? 'success' : 'danger'; ?>">
                                <?php echo htmlspecialchars($licenseData['remaining_days_display']); ?>
                            </p>
                        </div>
                    </div>
                <?php else: ?>
                    <div class="alert alert-warning">
                        <i class="bi bi-exclamation-triangle me-2"></i> Keine Lizenzinformationen verfügbar.
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <!-- Lagerplatz-Ebenen -->
        <div class="dashboard-card">
            <h5><i class="bi bi-stack"></i> Lagerplatz-Ebenen verwalten</h5>
            <form method="POST">
                <div id="ebenen-list">
                    <?php foreach ($lagerplatz_ebenen as $index => $ebene): ?>
                        <div class="input-group mb-3 ebene-item" draggable="true" data-index="<?php echo $index; ?>">
                            <span class="input-group-text handle"><i class="bi bi-list"></i></span>
                            <input type="text" name="ebenen_kurzel[]" class="form-control" value="<?php echo htmlspecialchars($ebene['kurzel']); ?>" placeholder="Kürzel (z. B. EG)" required>
                            <input type="text" name="ebenen_bezeichnung[]" class="form-control" value="<?php echo htmlspecialchars($ebene['bezeichnung']); ?>" placeholder="Bezeichnung (z. B. Erdgeschoss)" required>
                            <button type="button" class="btn btn-danger remove-ebene">Entfernen</button>
                        </div>
                    <?php endforeach; ?>
                </div>
                <button type="button" id="add-ebene" class="btn btn-success mb-3">+ Ebene hinzufügen</button>
                <button type="submit" class="btn btn-primary w-100">Speichern</button>
            </form>
        </div>

        <!-- Produkttypen-Zuordnung -->
        <div class="dashboard-card">
            <h5><i class="bi bi-boxes"></i> Produkttypen-Zuordnung</h5>
            <form method="POST">
                <div id="mapping-list">
                    <?php foreach ($mapping as $key => $value): ?>
                        <div class="input-group mb-3">
                            <input type="text" name="mapping_keys[]" class="form-control" value="<?php echo htmlspecialchars($key); ?>" placeholder="Produkttyp" required>
                            <input type="text" name="mapping_values[]" class="form-control" value="<?php echo htmlspecialchars($value); ?>" placeholder="Ebene" required>
                            <button type="button" class="btn btn-danger remove-mapping">Entfernen</button>
                        </div>
                    <?php endforeach; ?>
                </div>
                <button type="button" id="add-mapping" class="btn btn-success mb-3">+ Zuordnung hinzufügen</button>
                <button type="submit" class="btn btn-primary w-100">Speichern</button>
            </form>
        </div>

        <!-- Admin-Funktionen -->
        <?php if ($isAdmin): ?>
            <div class="dashboard-card">
                <h5><i class="bi bi-shield-lock-fill"></i> Admin-Funktionen</h5>
                <a href="users.php" class="btn btn-secondary w-100 mb-2"><i class="bi bi-people-fill"></i> Benutzerverwaltung</a>
                <a href="update.php" class="btn btn-secondary w-100 mb-2"><i class="bi bi-arrow-repeat"></i> System-Update</a>
                <a href="module_store.php" class="btn btn-primary w-100 mb-2"><i class="bi bi-shop-window me-1"></i> Modul Store</a>
            </div>
        <?php endif; ?>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function () {
    const ebeneList = document.getElementById('ebenen-list');
    const addEbeneButton = document.getElementById('add-ebene');
    const mappingList = document.getElementById('mapping-list');
    const addMappingButton = document.getElementById('add-mapping');

    // Funktion zum Hinzufügen einer neuen Ebene
    addEbeneButton.addEventListener('click', function () {
        const div = document.createElement('div');
        div.classList.add('input-group', 'mb-3', 'ebene-item');
        div.setAttribute('draggable', 'true');
        div.innerHTML = `
            <span class="input-group-text handle"><i class="bi bi-list"></i></span>
            <input type="text" name="ebenen_kurzel[]" class="form-control" placeholder="Kürzel (z. B. EG)" required>
            <input type="text" name="ebenen_bezeichnung[]" class="form-control" placeholder="Bezeichnung (z. B. Erdgeschoss)" required>
            <button type="button" class="btn btn-danger remove-ebene">Entfernen</button>
        `;
        ebeneList.appendChild(div);
    });

    // Funktion zum Hinzufügen einer neuen Zuordnung
    addMappingButton.addEventListener('click', function () {
        const div = document.createElement('div');
        div.classList.add('input-group', 'mb-3');
        div.innerHTML = `
            <input type="text" name="mapping_keys[]" class="form-control" placeholder="Produkttyp" required>
            <input type="text" name="mapping_values[]" class="form-control" placeholder="Ebene" required>
            <button type="button" class="btn btn-danger remove-mapping">Entfernen</button>
        `;
        mappingList.appendChild(div);
    });

    // Delegierter Event-Listener für die "Entfernen"-Buttons
    document.addEventListener('click', function (e) {
        if (e.target.classList.contains('remove-ebene')) {
            e.target.closest('.input-group').remove();
        }
        if (e.target.classList.contains('remove-mapping')) {
            e.target.closest('.input-group').remove();
        }
    });

    // Drag-and-Drop für Ebenen
    let draggedItem = null;

    ebeneList.addEventListener('dragstart', function (e) {
        if (e.target && e.target.classList.contains('ebene-item')) {
            draggedItem = e.target;
            e.target.classList.add('dragging');
            e.dataTransfer.effectAllowed = 'move';
        }
    });

    ebeneList.addEventListener('dragover', function (e) {
        e.preventDefault();
        const afterElement = getDragAfterElement(ebeneList, e.clientY);
        const draggable = document.querySelector('.dragging');
        if (afterElement == null) {
            ebeneList.appendChild(draggable);
        } else {
            ebeneList.insertBefore(draggable, afterElement);
        }
    });

    ebeneList.addEventListener('dragend', function (e) {
        if (e.target && e.target.classList.contains('ebene-item')) {
            e.target.classList.remove('dragging');
        }
        draggedItem = null;
    });

    function getDragAfterElement(container, y) {
        const draggableElements = [...container.querySelectorAll('.ebene-item:not(.dragging)')];

        return draggableElements.reduce((closest, child) => {
            const box = child.getBoundingClientRect();
            const offset = y - box.top - box.height / 2;
            if (offset < 0 && offset > closest.offset) {
                return { offset: offset, element: child };
            } else {
                return closest;
            }
        }, { offset: Number.NEGATIVE_INFINITY }).element;
    }
});
</script>

<!-- Bootstrap JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
