<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Neuen Artikel erstellen</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<?php include 'partials/navbar.php'; ?>

<div class="container my-5">
    <h1 class="text-center text-primary">Neuen Artikel erstellen</h1>

    <!-- Fehlermeldungen -->
    <?php if (isset($_SESSION['error'])): ?>
        <div class="alert alert-danger">
            <i class="bi bi-exclamation-triangle-fill"></i> <?= htmlspecialchars($_SESSION['error']) ?>
        </div>
        <?php unset($_SESSION['error']); ?>
    <?php endif; ?>

    <!-- Erfolgsmeldungen -->
    <?php if (isset($_SESSION['message'])): ?>
        <div class="alert alert-success">
            <i class="bi bi-check-circle-fill"></i> <?= htmlspecialchars($_SESSION['message']) ?>
        </div>
        <?php unset($_SESSION['message']); ?>
    <?php endif; ?>

    <!-- Formular -->
    <form action="index.php?action=saveArticleWithLagerplatz" method="post">
        <div class="row">
            <div class="col-md-6 mb-3">
                <label for="name" class="form-label">Artikelname</label>
                <input type="text" name="name" id="name" class="form-control" placeholder="Artikelname" required>
            </div>
            <div class="col-md-6 mb-3">
                <label for="sku" class="form-label">SKU (Artikelnummer)</label>
                <input type="text" name="sku" id="sku" class="form-control" placeholder="Artikelnummer" required>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6 mb-3">
                <label for="price" class="form-label">Preis (€)</label>
                <input type="number" name="price" id="price" class="form-control" placeholder="Preis" step="0.01" required>
            </div>
            <div class="col-md-6 mb-3">
                <label for="quantity" class="form-label">Menge</label>
                <input type="number" name="quantity" id="quantity" class="form-control" placeholder="Menge" required>
            </div>
        </div>
        <div class="mb-3">
            <label for="einheit" class="form-label">Einheit (z. B. Stück, Karton, Beutel)*</label>
            <input type="text" name="einheit" id="einheit" class="form-control" placeholder="z. B. Karton" required>
        </div>
        <div class="mb-3">
            <label for="einheit_faktor" class="form-label">Einheiten pro Verpackungseinheit (optional)</label>
            <input type="number" name="einheit_faktor" id="einheit_faktor" class="form-control" placeholder="z. B. 50 (wenn 1 Karton = 50 Stück ist)">
        </div>
        <div class="mb-3">
            <label for="lagerplatz_id" class="form-label">Lagerplatz</label>
            <select name="lagerplatz_id" id="lagerplatz_id" class="form-select" required>
                <?php foreach ($lagerplaetze as $lagerplatz): ?>
                    <option value="<?= $lagerplatz['id'] ?>"><?= htmlspecialchars($lagerplatz['name']) ?> (Kapazität: <?= $lagerplatz['kapazitaet'] ?>)</option>
                <?php endforeach; ?>
            </select>
        </div>
        <div class="mb-3">
            <label for="description" class="form-label">Beschreibung</label>
            <textarea name="description" id="description" class="form-control" rows="4" placeholder="Artikelbeschreibung"></textarea>
        </div>
        <div class="text-center">
            <button type="submit" class="btn btn-success btn-lg">
                <i class="bi bi-save"></i> Speichern
            </button>
            <a href="index.php?action=listArticles" class="btn btn-secondary btn-lg">
                <i class="bi bi-arrow-left"></i> Abbrechen
            </a>
        </div>
    </form>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
