<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Dashboard</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Chart.js für Diagramme -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        body {
            background-color: #f7f9fc;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }
        h1 {
            font-weight: 700;
            margin-bottom: 30px;
        }
        .table th, .table td {
            vertical-align: middle;
        }
        .card {
            border-radius: 15px;
        }
        .btn {
            border-radius: 50px;
            font-weight: 500;
        }
        .alert {
            border-radius: 50px;
            font-weight: 500;
        }
        .text-muted {
            opacity: 0.7;
        }
        .info-text {
            font-size: 0.9em;
            color: #555;
        }
        .chart-container {
            position: relative;
            margin: auto;
            height: 40vh;
            width: 80vw;
        }
    </style>
</head>
<body>
<?php include 'partials/navbar.php'; ?>

<div class="container my-5">
    <h1 class="text-center text-primary">Dashboard</h1>

    <!-- Meldungen -->
    <?php if (isset($_SESSION['message'])): ?>
        <div class="alert alert-success text-center" role="alert">
            <i class="bi bi-check-circle-fill me-2"></i><?= htmlspecialchars($_SESSION['message']); ?>
        </div>
        <?php unset($_SESSION['message']); ?>
    <?php endif; ?>

    <?php if (isset($_SESSION['error'])): ?>
        <div class="alert alert-danger text-center" role="alert">
            <i class="bi bi-exclamation-triangle-fill me-2"></i><?= htmlspecialchars($_SESSION['error']); ?>
        </div>
        <?php unset($_SESSION['error']); ?>
    <?php endif; ?>

    <!-- Statistikkarten -->
    <div class="row">
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-primary">
                <div class="card-body">
                    <h5>Gesamt Lagerplätze</h5>
                    <h3><?= htmlspecialchars($totalLagerplaetze) ?></h3>
                </div>
            </div>
        </div>
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-success">
                <div class="card-body">
                    <h5>Belegte Plätze</h5>
                    <h3><?= htmlspecialchars($totalBelegung) ?></h3>
                </div>
            </div>
        </div>
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-warning">
                <div class="card-body">
                    <h5>Freie Kapazität</h5>
                    <h3><?= htmlspecialchars($freieKapazitaet) ?></h3>
                </div>
            </div>
        </div>
        <div class="col-lg-3 col-md-6 mb-4">
            <div class="card text-white bg-info">
                <div class="card-body">
                    <h5>Durchschnittliche Auslastung</h5>
                    <h3><?= htmlspecialchars(round($durchschnittlicheAuslastung, 2)) ?>%</h3>
                </div>
            </div>
        </div>
    </div>

    <!-- Diagramme -->
    <div class="row mb-5">
        <div class="col-md-6">
            <h4 class="text-center">Lagerplatz Auslastung</h4>
            <canvas id="lagerplatzChart"></canvas>
        </div>
        <div class="col-md-6">
            <h4 class="text-center">Top 5 Meistgelagerte Artikel</h4>
            <canvas id="topArtikelChart"></canvas>
        </div>
    </div>

    <!-- Lagerplatzübersicht -->
    <div class="mb-5">
        <h2>Lagerplatzübersicht</h2>
        <?php if (!empty($allLagerplaetze)): ?>
            <div class="table-responsive">
                <table class="table table-bordered table-striped align-middle">
                    <thead class="table-light">
                        <tr>
                            <th>ID</th>
                            <th>Name</th>
                            <th>Kapazität</th>
                            <th>Belegung</th>
                            <th>Freie Kapazität</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($allLagerplaetze as $lp): ?>
                            <tr>
                                <td><?= htmlspecialchars($lp['id']); ?></td>
                                <td><?= htmlspecialchars($lp['name']); ?></td>
                                <td><?= htmlspecialchars($lp['kapazitaet']); ?></td>
                                <td><?= htmlspecialchars($lp['belegung']); ?></td>
                                <td><?= htmlspecialchars($lp['freie_kapazitaet']); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <p class="text-muted">Keine Lagerplätze vorhanden.</p>
        <?php endif; ?>
    </div>

    <!-- Artikelübersicht -->
    <div class="mb-5">
        <h2>Artikelübersicht</h2>
        <?php if (!empty($allArtikel)): ?>
            <div class="table-responsive">
                <table class="table table-bordered table-striped align-middle">
                    <thead class="table-light">
                        <tr>
                            <th>ID</th>
                            <th>Name</th>
                            <th>SKU</th>
                            <th>Preis (€)</th>
                            <th>Einheit</th>
                            <th>Faktor</th>
                            <th>Gesamtbestand (Stück)</th>
                            <th>Lagerplätze</th>
                            <th>Erstellt am</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($allArtikel as $article):
                            // Einheit und Faktor, falls vorhanden
                            $einheit = $article['einheit'] ?? 'Stück';
                            $faktor = (int)($article['einheit_faktor'] ?? 1);
                            if ($faktor <= 0) { 
                                $faktor = 1; 
                            }
                            // total_stueck kommt aus der SQL-Abfrage
                            $total_stueck = (int)$article['total_stueck'];
                        ?>
                            <tr>
                                <td><?= htmlspecialchars($article['id']); ?></td>
                                <td><?= htmlspecialchars($article['name']); ?></td>
                                <td><?= htmlspecialchars($article['sku']); ?></td>
                                <td><?= htmlspecialchars(number_format($article['price'], 2, ',', '.')); ?> €</td>
                                <td><?= htmlspecialchars($einheit); ?></td>
                                <td><?= htmlspecialchars($faktor); ?></td>
                                <td><?= htmlspecialchars($total_stueck); ?> Stück</td>
                                <td>
                                    <?php if (!empty($article['lagerplaetze_namen'])): ?>
                                        <?= htmlspecialchars($article['lagerplaetze_namen']); ?>
                                    <?php else: ?>
                                        <span class="text-muted">Nicht zugeordnet</span>
                                    <?php endif; ?>
                                </td>
                                <td><?= htmlspecialchars(date('d.m.Y H:i', strtotime($article['erstellt_am']))); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <p class="text-muted">Keine Artikel vorhanden.</p>
        <?php endif; ?>
    </div>

    <!-- Neueste EB-Einträge -->
    <div class="mb-5">
        <h2>Neueste erwartete Wareneingänge (EB)</h2>
        <?php if (!empty($latest5EB)): ?>
            <div class="table-responsive">
                <table class="table table-bordered table-striped align-middle">
                    <thead class="table-light">
                        <tr>
                            <th>EB-Nummer</th>
                            <th>Artikel</th>
                            <th>Gesamtmenge</th>
                            <th>Menge offen</th>
                            <th>Status</th>
                            <th>Erstellt am</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($latest5EB as $eb): 
                            $artikel = getArticleById($eb['artikel_id']);
                            $einheit = $artikel['einheit'] ?? 'Stück';
                            $faktor = (int)$artikel['einheit_faktor'];
                            if ($faktor <= 0) { $faktor = 1; }

                            // Umrechnung
                            $menge_gesamt_stueck = $eb['menge_gesamt'] * $faktor;
                            $menge_offen_stueck = $eb['menge_offen'] * $faktor;
                        ?>
                            <tr>
                                <td><?= htmlspecialchars($eb['eb_nummer']); ?></td>
                                <td><?= htmlspecialchars($artikel['name'] . " (SKU: " . $artikel['sku'] . ")"); ?></td>
                                <td>
                                    <?= htmlspecialchars($eb['menge_gesamt']) . " " . htmlspecialchars($einheit); ?><br>
                                    <small class="text-muted">(entspricht <?= htmlspecialchars($menge_gesamt_stueck); ?> Stück)</small>
                                </td>
                                <td>
                                    <?= htmlspecialchars($eb['menge_offen']) . " " . htmlspecialchars($einheit); ?><br>
                                    <small class="text-muted">(entspricht <?= htmlspecialchars($menge_offen_stueck); ?> Stück)</small>
                                </td>
                                <td><?= htmlspecialchars($eb['status']); ?></td>
                                <td><?= htmlspecialchars(date('d.m.Y H:i', strtotime($eb['erstellt_am']))); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <p class="text-muted">Keine EB-Einträge vorhanden.</p>
        <?php endif; ?>
    </div>

</div>

<!-- Diagramme Scripts -->
<script>
    // Lagerplatz Auslastung Pie Chart
    const ctx1 = document.getElementById('lagerplatzChart').getContext('2d');
    const lagerplatzChart = new Chart(ctx1, {
        type: 'pie',
        data: {
            labels: ['Belegt', 'Frei'],
            datasets: [{
                label: 'Lagerplatz Auslastung',
                data: [<?= htmlspecialchars($totalBelegung) ?>, <?= htmlspecialchars($freieKapazitaet) ?>],
                backgroundColor: [
                    'rgba(40, 167, 69, 0.7)', // Grün für Belegt
                    'rgba(23, 162, 184, 0.7)'  // Blau für Frei
                ],
                borderColor: [
                    'rgba(40, 167, 69, 1)',
                    'rgba(23, 162, 184, 1)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true
        }
    });

    // Top 5 Artikel Bar Chart
    const ctx2 = document.getElementById('topArtikelChart').getContext('2d');
    const topArtikelLabels = [<?php foreach ($top5Artikel as $ta) { echo "'" . addslashes($ta['name']) . "',"; } ?>];
    const topArtikelData = [<?php foreach ($top5Artikel as $ta) { echo htmlspecialchars($ta['total_stueck']) . ","; } ?>];

    const topArtikelChart = new Chart(ctx2, {
        type: 'bar',
        data: {
            labels: topArtikelLabels,
            datasets: [{
                label: 'Gesamtbestand (Stück)',
                data: topArtikelData,
                backgroundColor: 'rgba(255, 193, 7, 0.7)', // Gelb für Top Artikel
                borderColor: 'rgba(255, 193, 7, 1)',
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        }
    });
</script>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
