<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Lagerplatz Übersicht</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Chart.js -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <!-- Font Awesome für Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" integrity="sha512-Fo3rlrZj/k7ujTTXRNtPV+XnS7LP12gS7q4I8+0FVuK/9IkeMQYf/kU4HDA5u0kIfX6fPfB6YQ0eZP3xV4EBw==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <!-- Custom Styles -->
    <style>
        body {
            background-color: #f4f6f9;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }
        h1 {
            margin-bottom: 30px;
            font-weight: 700;
            color: #343a40;
        }
        .lagerplatz-card {
            transition: transform 0.3s, box-shadow 0.3s;
            cursor: pointer;
        }
        .lagerplatz-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 20px rgba(0,0,0,0.2);
        }
        .status-indicator {
            width: 15px;
            height: 15px;
            border-radius: 50%;
            display: inline-block;
            margin-right: 5px;
        }
        .status-frei {
            background-color: #28a745;
        }
        .status-belegt {
            background-color: #ffc107;
        }
        .status-kritisch {
            background-color: #dc3545;
        }
        .card-title {
            font-size: 1.25rem;
            font-weight: 600;
        }
        .badge-custom {
            font-size: 0.85rem;
            padding: 0.5em 0.75em;
        }
        .chart-container {
            position: relative;
            margin: auto;
            height: 40vh;
            width: 80vw;
        }
        .search-bar {
            max-width: 300px;
        }
        .filter-btn {
            margin-left: 10px;
        }
    </style>
</head>
<body>
    <?php include 'partials/navbar.php'; ?>

    <div class="container my-5">
        <h1 class="text-center">Lagerplatz Übersicht</h1>

        <!-- Fehlermeldungen -->
        <?php if (isset($_SESSION['message'])): ?>
            <div class="alert alert-success text-center" role="alert">
                <i class="fas fa-check-circle me-2"></i><?= htmlspecialchars($_SESSION['message']); ?>
            </div>
            <?php unset($_SESSION['message']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger text-center" role="alert">
                <i class="fas fa-exclamation-triangle me-2"></i><?= htmlspecialchars($_SESSION['error']); ?>
            </div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- Such- und Filterfunktion -->
        <div class="row mb-4">
            <div class="col-md-6">
                <input type="text" id="searchInput" class="form-control search-bar" placeholder="Suche Lagerplätze...">
            </div>
            <div class="col-md-6 text-md-end mt-2 mt-md-0">
                <button class="btn btn-secondary filter-btn" id="resetFilters"><i class="fas fa-undo"></i> Filter zurücksetzen</button>
            </div>
        </div>

        <!-- Lagerplätze anzeigen -->
        <?php if (!empty($lagerplaetze)): ?>
            <div class="row" id="lagerplaetzeContainer">
                <?php foreach ($lagerplaetze as $lp): ?>
                    <?php 
                        // Bestimmen des Statusindikators basierend auf der freien Kapazität
                        $kapazitaet = $lp['kapazitaet'];
                        $belegung = $lp['belegung'];
                        $freie_kapazitaet = $lp['freie_kapazitaet'];
                        $auslastung = ($kapazitaet > 0) ? ($belegung / $kapazitaet) * 100 : 0;

                        if ($auslastung < 80) {
                            $status_class = 'status-frei';
                            $status_text = 'Frei';
                        } elseif ($auslastung < 90) {
                            $status_class = 'status-belegt';
                            $status_text = 'Belegt';
                        } else {
                            $status_class = 'status-kritisch';
                            $status_text = 'Kritisch';
                        }
                    ?>
                    <div class="col-md-6 col-lg-4 mb-4 lagerplatz-card" data-name="<?= strtolower(htmlspecialchars($lp['name'])); ?>" data-belegung="<?= $lp['belegung']; ?>">
                        <div class="card h-100 shadow-sm">
                            <div class="card-body d-flex flex-column">
                                <div class="d-flex justify-content-between align-items-center mb-3">
                                    <h5 class="card-title mb-0">
                                        <span class="status-indicator <?= $status_class; ?>"></span>
                                        <?= htmlspecialchars($lp['name']); ?>
                                    </h5>
                                    <span class="badge bg-primary badge-custom">
                                        <?= htmlspecialchars($freie_kapazitaet); ?> frei
                                    </span>
                                </div>
                                <p class="card-text mb-4">
                                    <strong>Kapazität:</strong> <?= htmlspecialchars($kapazitaet); ?><br>
                                    <strong>Belegung:</strong> <?= htmlspecialchars($belegung); ?><br>
                                    <strong>Freie Kapazität:</strong> <?= htmlspecialchars($freie_kapazitaet); ?>
                                </p>
                                <div class="progress mb-3" style="height: 20px;">
                                    <?php 
                                        $progress_percentage = round($auslastung, 2);
                                        if ($progress_percentage < 80) {
                                            $progress_color = 'bg-success';
                                        } elseif ($progress_percentage < 90) {
                                            $progress_color = 'bg-warning';
                                        } else {
                                            $progress_color = 'bg-danger';
                                        }
                                    ?>
                                    <div class="progress-bar <?= $progress_color; ?>" role="progressbar" style="width: <?= $progress_percentage; ?>%;" aria-valuenow="<?= $progress_percentage; ?>" aria-valuemin="0" aria-valuemax="100"><?= $progress_percentage; ?>%</div>
                                </div>
                                <div class="mt-auto">
                                    <?php if (!empty($lp['artikel'])): ?>
                                        <button class="btn btn-outline-primary btn-sm w-100" data-bs-toggle="modal" data-bs-target="#artikelModal<?= $lp['id']; ?>">
                                            <i class="fas fa-boxes me-2"></i> Artikel anzeigen
                                        </button>
                                    <?php else: ?>
                                        <button class="btn btn-outline-secondary btn-sm w-100" disabled>
                                            <i class="fas fa-boxes me-2"></i> Keine Artikel
                                        </button>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Modal für Artikel (nur wenn Artikel vorhanden sind) -->
                    <?php if (!empty($lp['artikel'])): ?>
                        <div class="modal fade" id="artikelModal<?= $lp['id']; ?>" tabindex="-1" aria-labelledby="artikelModalLabel<?= $lp['id']; ?>" aria-hidden="true">
                            <div class="modal-dialog modal-xl modal-dialog-scrollable">
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h5 class="modal-title" id="artikelModalLabel<?= $lp['id']; ?>">Artikel auf <?= htmlspecialchars($lp['name']); ?></h5>
                                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Schließen"></button>
                                    </div>
                                    <div class="modal-body">
                                        <?php if (!empty($lp['artikel'])): ?>
                                            <div class="table-responsive">
                                                <table class="table table-hover table-striped">
                                                    <thead class="table-light">
                                                        <tr>
                                                            <th>ID</th>
                                                            <th>Name</th>
                                                            <th>SKU</th>
                                                            <th>Menge</th>
                                                            <th>Einheit</th>
                                                            <th>Stückzahl</th>
                                                            <th>Details</th>
                                                        </tr>
                                                    </thead>
                                                    <tbody>
                                                        <?php foreach ($lp['artikel'] as $artikel): ?>
                                                            <tr>
                                                                <td><?= htmlspecialchars($artikel['id']); ?></td>
                                                                <td><?= htmlspecialchars($artikel['name']); ?></td>
                                                                <td><?= htmlspecialchars($artikel['sku']); ?></td>
                                                                <td><?= htmlspecialchars($artikel['menge']); ?></td>
                                                                <td><?= htmlspecialchars($artikel['einheit']); ?></td>
                                                                <td><?= htmlspecialchars($artikel['menge'] * $artikel['einheit_faktor']); ?> Stück</td>
                                                                <td>
                                                                    <a href="index.php?action=editArticle&id=<?= htmlspecialchars($artikel['id']); ?>" class="btn btn-sm btn-outline-secondary">
                                                                        <i class="fas fa-edit"></i> Bearbeiten
                                                                    </a>
                                                                </td>
                                                            </tr>
                                                        <?php endforeach; ?>
                                                    </tbody>
                                                </table>
                                            </div>
                                        <?php else: ?>
                                            <p class="text-muted">Keine Artikel auf diesem Lagerplatz.</p>
                                        <?php endif; ?>
                                    </div>
                                    <div class="modal-footer">
                                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Schließen</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                <?php endforeach; ?>
            </div>

            <!-- Diagramm: Gesamte Lagerplatz Auslastung -->
            <div class="my-5">
                <h2 class="text-center mb-4">Gesamte Lagerplatz Auslastung</h2>
                <div class="chart-container">
                    <canvas id="auslastungChart"></canvas>
                </div>
            </div>
        <?php else: ?>
            <p class="text-muted text-center">Keine Lagerplätze vorhanden.</p>
        <?php endif; ?>
    </div>

    <!-- JavaScript für Filter und Diagramm -->
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const searchInput = document.getElementById('searchInput');
            const resetFilters = document.getElementById('resetFilters');
            const lagerplaetzeContainer = document.getElementById('lagerplaetzeContainer');
            const lagerplatzCards = document.querySelectorAll('.lagerplatz-card');

            // Suchfunktion
            searchInput.addEventListener('keyup', function () {
                const filter = this.value.toLowerCase();
                lagerplatzCards.forEach(card => {
                    const name = card.getAttribute('data-name');
                    if (name.includes(filter)) {
                        card.style.display = '';
                    } else {
                        card.style.display = 'none';
                    }
                });
            });

            // Filter zurücksetzen
            resetFilters.addEventListener('click', function () {
                searchInput.value = '';
                lagerplatzCards.forEach(card => {
                    card.style.display = '';
                });
            });

            // Diagramm erstellen
            const ctx = document.getElementById('auslastungChart').getContext('2d');
            const auslastungChart = new Chart(ctx, {
                type: 'doughnut',
                data: {
                    labels: ['Belegt', 'Frei'],
                    datasets: [{
                        data: [
                            <?= htmlspecialchars($gesamtBelegung = array_sum(array_column($lagerplaetze, 'belegung'))); ?>, 
                            <?= htmlspecialchars($gesamtKapazitaet = array_sum(array_column($lagerplaetze, 'kapazitaet')) - $gesamtBelegung); ?>
                        ],
                        backgroundColor: [
                            'rgba(54, 162, 235, 0.8)', // Blau für Belegt
                            'rgba(75, 192, 192, 0.8)'  // Grün für Frei
                        ],
                        borderColor: [
                            'rgba(54, 162, 235, 1)',
                            'rgba(75, 192, 192, 1)'
                        ],
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    plugins: {
                        legend: {
                            position: 'bottom',
                            labels: {
                                boxWidth: 20,
                                padding: 15
                            }
                        },
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    let label = context.label || '';
                                    if (label) {
                                        label += ': ';
                                    }
                                    if (context.parsed !== null) {
                                        label += context.parsed;
                                    }
                                    return label;
                                }
                            }
                        },
                        title: {
                            display: false,
                            text: 'Lagerplatz Auslastung'
                        }
                    }
                }
            });
        });
    </script>

    <!-- Bootstrap JS und Abhängigkeiten -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
