<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

$moduleInstalled = file_exists(__DIR__ . '/MODUL/install.lock');

$mitarbeiter_id = $_SESSION['user_id'];
$errors = [];
$message = "";

// Ebenen aus der `settings`-Tabelle laden
$stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "lagerplatz_ebenen" LIMIT 1');
$stmt->execute();
$ebenenSetting = $stmt->fetch();
$verfuegbare_ebenen = $ebenenSetting ? json_decode($ebenenSetting['value'], true) : [];

// Verarbeitung der Formulareingabe
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        $action = $_POST['action']; // 'start', 'weiter', 'zurueck', 'ueberspringen', 'abbrechen', 'updateDatabase'

        if ($action === 'start') {
            // Verarbeiten der Ebenenauswahl
            if (isset($_POST['ebenen'])) {
                $ausgewaehlte_ebenen = $_POST['ebenen'];

                if (in_array('Alles', $ausgewaehlte_ebenen)) {
                    // 'Alles' ausgewählt: alle Kürzel der Ebenen extrahieren
                    $ausgewaehlte_ebenen = array_map(function ($ebene) {
                        return strtoupper($ebene['kurzel']); // Sicherstellen, dass Kürzel groß geschrieben sind
                    }, $verfuegbare_ebenen);
                } else {
                    // Kürzel ebenfalls groß schreiben, um Konsistenz sicherzustellen
                    $ausgewaehlte_ebenen = array_map('strtoupper', $ausgewaehlte_ebenen);
                }

                if (empty($ausgewaehlte_ebenen)) {
                    $errors[] = "Bitte wählen Sie mindestens eine Ebene aus.";
                } else {
                    // Initialisierung: Einträge für die ausgewählten Ebenen erstellen
                    $stmt = $pdo->prepare('SELECT id, name, ebene FROM lagerplaetze ORDER BY id ASC');
                    $stmt->execute();
                    $lagerplaetze = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    $stmtInsert = $pdo->prepare('INSERT INTO kapazitaet_progress (mitarbeiter_id, lagerplatz_id, kapazitaet, completed, timestamp) VALUES (?, ?, 0, 0, NOW())');

                    foreach ($lagerplaetze as $lagerplatz) {
                        // Ebene direkt aus dem `ebene`-Feld beziehen
                        $ebene = strtoupper($lagerplatz['ebene']);

                        if (in_array($ebene, $ausgewaehlte_ebenen)) {
                            // Prüfen, ob bereits ein Eintrag existiert
                            $stmtCheck = $pdo->prepare('SELECT COUNT(*) FROM kapazitaet_progress WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                            $stmtCheck->execute([$mitarbeiter_id, $lagerplatz['id']]);
                            $exists = $stmtCheck->fetchColumn() > 0;

                            if (!$exists) {
                                // Eintrag hinzufügen
                                $stmtInsert->execute([$mitarbeiter_id, $lagerplatz['id']]);
                            }
                        }
                    }

                    header('Location: kapazitaet.php');
                    exit();
                }
            } else {
                $errors[] = "Keine Ebenen ausgewählt.";
            }
        } elseif ($action === 'updateDatabase') {
            // Beginne eine Transaktion
            $pdo->beginTransaction();

            try {
                // Hole alle Einträge
                $stmt = $pdo->prepare('SELECT lagerplatz_id, kapazitaet, completed FROM kapazitaet_progress WHERE mitarbeiter_id = ?');
                $stmt->execute([$mitarbeiter_id]);
                $kapazitaetData = $stmt->fetchAll(PDO::FETCH_ASSOC);

                // Prepared Statements vorbereiten
                $stmtGetOld = $pdo->prepare('SELECT kapazitaet FROM lagerplaetze WHERE id = ?');
                $stmtUpdateLagerplatz = $pdo->prepare('UPDATE lagerplaetze SET kapazitaet = ? WHERE id = ?');
                $stmtInsertLog = $pdo->prepare('INSERT INTO kapazitaet_protokoll (lagerplatz_id, alte_kapazitaet, neue_kapazitaet, datum, mitarbeiter_id) VALUES (?, ?, ?, NOW(), ?)');

                foreach ($kapazitaetData as $data) {
                    $lagerplatzId = $data['lagerplatz_id'];
                    $neueKapazitaet = $data['kapazitaet'];
                    $completed = $data['completed'];

                    // Alte Kapazität abrufen
                    $stmtGetOld->execute([$lagerplatzId]);
                    $alteKapazitaet = $stmtGetOld->fetchColumn();

                    if ($completed == 1) {
                        // Kapazität aktualisieren
                        $stmtUpdateLagerplatz->execute([$neueKapazitaet, $lagerplatzId]);

                        // In Kapazitätsprotokoll eintragen
                        $stmtInsertLog->execute([$lagerplatzId, $alteKapazitaet, $neueKapazitaet, $mitarbeiter_id]);
                    } elseif ($completed == 2) {
                        // Übersprungene Einträge: Kapazität bleibt unverändert
                        $stmtInsertLog->execute([$lagerplatzId, $alteKapazitaet, $alteKapazitaet, $mitarbeiter_id]);
                    }
                }

                // Fortschritt aus der kapazitaet_progress-Tabelle löschen
                $stmtDeleteProgress = $pdo->prepare('DELETE FROM kapazitaet_progress WHERE mitarbeiter_id = ?');
                $stmtDeleteProgress->execute([$mitarbeiter_id]);

                // Transaktion abschließen
                $pdo->commit();

                $message = "Die Kapazitäten wurden erfolgreich aktualisiert.";
            } catch (Exception $e) {
                // Bei Fehlern die Transaktion zurücksetzen
                $pdo->rollBack();
                $errors[] = "Es ist ein Fehler aufgetreten: " . htmlspecialchars($e->getMessage());
            }
        } elseif ($action === 'abbrechen') {
            // Fortschritt löschen
            $stmtDeleteProgress = $pdo->prepare('DELETE FROM kapazitaet_progress WHERE mitarbeiter_id = ?');
            $stmtDeleteProgress->execute([$mitarbeiter_id]);

            $message = "Die Aktualisierung wurde abgebrochen und zurückgesetzt.";
        } else {
            // Andere Aktionen: 'weiter', 'zurueck', 'ueberspringen'
            if (isset($_POST['lagerplatz_id'])) {
                $lagerplatz_id = (int)$_POST['lagerplatz_id'];

                if ($action === 'weiter') {
                    if (isset($_POST['kapazitaet']) && $_POST['kapazitaet'] !== '') {
                        $kapazitaet = (int)$_POST['kapazitaet'];

                        // Validierung der eingegebenen Kapazität (muss >= 0 sein)
                        if ($kapazitaet >= 0) {
                            // Aktualisierung der kapazitaet_progress-Tabelle
                            $stmt = $pdo->prepare('UPDATE kapazitaet_progress SET kapazitaet = ?, completed = 1 WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                            $stmt->execute([$kapazitaet, $mitarbeiter_id, $lagerplatz_id]);
                        } else {
                            $errors[] = "Die eingegebene Kapazität muss größer oder gleich 0 sein.";
                        }
                    } else {
                        $errors[] = "Bitte geben Sie eine Kapazität ein.";
                    }
                } elseif ($action === 'zurueck') {
                    // Setze den aktuellen Lagerplatz zurück auf pending
                    $stmtUpdateCurrent = $pdo->prepare('UPDATE kapazitaet_progress SET completed = 0 WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                    $stmtUpdateCurrent->execute([$mitarbeiter_id, $lagerplatz_id]);

                    // Finde den vorherigen Lagerplatz
                    $stmtPrev = $pdo->prepare('
                        SELECT lp.id
                        FROM lagerplaetze lp
                        JOIN kapazitaet_progress kp ON lp.id = kp.lagerplatz_id
                        WHERE kp.mitarbeiter_id = ? AND lp.id < ? 
                        ORDER BY lp.id DESC
                        LIMIT 1
                    ');
                    $stmtPrev->execute([$mitarbeiter_id, $lagerplatz_id]);
                    $prevLagerplatz = $stmtPrev->fetch(PDO::FETCH_ASSOC);

                    if ($prevLagerplatz) {
                        $currentLagerplatzId = $prevLagerplatz['id'];
                    } else {
                        $errors[] = "Kein vorheriger Lagerplatz vorhanden.";
                    }
                } elseif ($action === 'ueberspringen') {
                    // Setze den aktuellen Lagerplatz auf übersprungen
                    $stmtUpdate = $pdo->prepare('UPDATE kapazitaet_progress SET kapazitaet = NULL, completed = 2 WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                    $stmtUpdate->execute([$mitarbeiter_id, $lagerplatz_id]);
                }
            }
        }
    }
}

// Überprüfung, ob der Benutzer bereits einen Fortschritt hat
$stmt = $pdo->prepare('SELECT COUNT(*) FROM kapazitaet_progress WHERE mitarbeiter_id = ?');
$stmt->execute([$mitarbeiter_id]);
$progressExists = $stmt->fetchColumn() > 0;

if (!$progressExists) {
    $show_ebenen_auswahl = true;
} else {
    $show_ebenen_auswahl = false;
}

// Berechnung des Fortschritts, wenn ein Fortschritt existiert
if ($progressExists && !$show_ebenen_auswahl) {
    // Berechnung des Fortschritts
    $stmt = $pdo->prepare('SELECT COUNT(*) FROM kapazitaet_progress WHERE mitarbeiter_id = ?');
    $stmt->execute([$mitarbeiter_id]);
    $total = $stmt->fetchColumn();

    $stmt = $pdo->prepare('SELECT COUNT(*) FROM kapazitaet_progress WHERE mitarbeiter_id = ? AND completed IN (1,2)');
    $stmt->execute([$mitarbeiter_id]);
    $completed = $stmt->fetchColumn();

    $progressPercentage = ($total > 0) ? round(($completed / $total) * 100, 2) : 0;

    // Nächsten Lagerplatz abrufen, der noch nicht abgeschlossen ist
    if (!isset($currentLagerplatzId)) {
        $stmt = $pdo->prepare('
            SELECT kp.lagerplatz_id, lp.name, lp.kapazitaet
            FROM kapazitaet_progress kp
            JOIN lagerplaetze lp ON kp.lagerplatz_id = lp.id
            WHERE kp.mitarbeiter_id = ? AND kp.completed = 0
            ORDER BY FIELD(lp.ebene, ' . implode(',', array_map(function($e) { return "'" . strtoupper($e['kurzel']) . "'"; }, $verfuegbare_ebenen)) . '), lp.id ASC
            LIMIT 1
        ');
        $stmt->execute([$mitarbeiter_id]);
        $currentLagerplatz = $stmt->fetch(PDO::FETCH_ASSOC);
    } else {
        // Lagerplatz mit der ID $currentLagerplatzId abrufen
        $stmt = $pdo->prepare('
            SELECT kp.lagerplatz_id, lp.name, lp.kapazitaet
            FROM kapazitaet_progress kp
            JOIN lagerplaetze lp ON kp.lagerplatz_id = lp.id
            WHERE kp.lagerplatz_id = ?
        ');
        $stmt->execute([$currentLagerplatzId]);
        $currentLagerplatz = $stmt->fetch(PDO::FETCH_ASSOC);
    }

    // Falls es keinen aktuellen Lagerplatz gibt, prüfen wir auf übersprungene Lagerplätze
    if (!$currentLagerplatz && !isset($message)) {
        $stmt = $pdo->prepare('
            SELECT kp.lagerplatz_id, lp.name, lp.kapazitaet
            FROM kapazitaet_progress kp
            JOIN lagerplaetze lp ON kp.lagerplatz_id = lp.id
            WHERE kp.mitarbeiter_id = ? AND kp.completed = 2
            ORDER BY FIELD(lp.ebene, ' . implode(',', array_map(function($e) { return "'" . strtoupper($e['kurzel']) . "'"; }, $verfuegbare_ebenen)) . '), lp.id ASC
            LIMIT 1
        ');
        $stmt->execute([$mitarbeiter_id]);
        $currentLagerplatz = $stmt->fetch(PDO::FETCH_ASSOC);
    }
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Kapazität aktualisieren</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;500;700&display=swap" rel="stylesheet">
    <!-- Eigenes CSS -->
    <style>
        /* Farbvariablen */
        :root {
            --primary-color: #1a1a2e;
            --secondary-color: #16213e;
            --accent-color: #0f3460;
            --highlight-color: #e94560;
            --background-color: #f0f2f5;
            --light-color: #ffffff;
            --text-color: #333333;
            --shadow-color: rgba(0, 0, 0, 0.1);
            --transition-speed: 0.3s;
        }

        body {
            background-color: var(--background-color);
            font-family: 'Roboto', sans-serif;
            color: var(--text-color);
            padding-bottom: 60px; /* Platz für die mobile Navigation */
        }

        /* Navbar Styling */
        .navbar {
            background-color: var(--primary-color);
            height: 86px;
            box-shadow: 0 4px 6px var(--shadow-color);
            transition: background-color var(--transition-speed), box-shadow var(--transition-speed);
        }

        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            height: 66px;
            display: flex;
            align-items: center;
        }

        .navbar-brand img {
            height: 100%;
            width: auto;
            object-fit: contain;
        }

        .navbar-nav .nav-link {
            color: var(--light-color) !important;
            font-weight: 500;
            transition: color var(--transition-speed);
        }

        .navbar-nav .nav-link:hover {
            color: var(--highlight-color) !important;
        }

        /* Kapazität Container */
        .inventur-container {
            max-width: 800px;
            margin: 20px auto;
            text-align: center;
            background-color: var(--light-color);
            padding: 30px;
            border-radius: 15px;
            box-shadow: 0 4px 6px var(--shadow-color);
        }

        .inventur-container h2 {
            font-family: 'Roboto', sans-serif;
            font-weight: 700;
            margin-bottom: 30px;
            color: var(--primary-color);
        }

        .lagerplatz-name {
            font-size: 2em;
            margin-bottom: 20px;
            font-weight: bold;
            color: var(--secondary-color);
        }

        .current-capacity {
            font-size: 1.5em;
            color: var(--accent-color);
            margin-bottom: 30px;
        }

        .input-group {
            margin-bottom: 25px;
        }

        .btn-action {
            width: 100%;
            font-size: 1.1em;
            padding: 12px;
            margin-bottom: 15px;
            border-radius: 50px;
            transition: background-color var(--transition-speed), transform var(--transition-speed);
        }

        .btn-action:hover {
            transform: translateY(-3px);
        }

        .btn-primary {
            background-color: var(--highlight-color);
            border: none;
        }

        .btn-primary:hover {
            background-color: #c0392b;
        }

        .btn-secondary {
            background-color: var(--accent-color);
            border: none;
            color: var(--light-color);
        }

        .btn-secondary:hover {
            background-color: #34495e;
        }

        .btn-warning {
            background-color: #f1c40f;
            border: none;
            color: var(--light-color);
        }

        .btn-warning:hover {
            background-color: #d4ac0d;
        }

        .btn-danger {
            background-color: #e74c3c;
            border: none;
            color: var(--light-color);
        }

        .btn-danger:hover {
            background-color: #c0392b;
        }

        /* Fortschrittsbalken */
        .progress {
            height: 25px;
            margin-bottom: 30px;
            background-color: #e9ecef;
            border-radius: 15px;
            overflow: hidden;
        }

        .progress-bar {
            font-size: 1em;
            line-height: 25px;
            background: linear-gradient(45deg, #1abc9c, #2ecc71);
        }

        /* Mobile Optimierung */
        @media (max-width: 767px) {
            .inventur-container {
                margin: 10px;
                padding: 20px;
            }

            .lagerplatz-name {
                font-size: 1.5em;
            }

            .current-capacity {
                font-size: 1.2em;
            }

            .btn-action {
                font-size: 1em;
                padding: 10px;
            }

            .navbar-brand {
                font-size: 1.2em;
            }
        }

        /* Mobile Bottom Navigation */
        .mobile-nav {
            display: none;
        }

        @media (max-width: 767px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: var(--primary-color);
                border-top: 1px solid #495057;
                justify-content: space-around;
                padding: 10px 0;
                z-index: 1000;
            }

            .mobile-nav a {
                color: var(--light-color);
                text-decoration: none;
                font-size: 0.85em;
                text-align: center;
                flex: 1;
                display: flex;
                flex-direction: column;
                align-items: center;
            }

            .mobile-nav a i {
                font-size: 1.5em;
                margin-bottom: 2px;
            }

            .mobile-nav a.active {
                color: var(--highlight-color);
            }
        }

        /* Tooltip-Stil */
        .tooltip-inner {
            max-width: 200px;
            padding: .25rem .5rem;
            color: #fff;
            text-align: center;
            background-color: #000;
            border-radius: .25rem;
        }

        /* Verbesserte Ebenenauswahl */
        .ebenen-auswahl .form-check {
            display: inline-block;
            width: 45%;
            margin: 5px 2.5%;
        }

        .ebenen-auswahl .form-check-input {
            width: 1.5em;
            height: 1.5em;
        }

        .ebenen-auswahl .form-check-label {
            font-size: 1.2em;
            margin-left: 0.5em;
        }

        .ebenen-auswahl h3 {
            font-weight: 700;
            color: var(--primary-color);
            margin-bottom: 20px;
        }

        /* Alerts */
        .alert-success {
            background-color: #d4edda;
            color: #155724;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
        }

        /* Input Styling */
        .input-group .form-control {
            font-size: 1.2em;
            padding: 15px;
            border-radius: 50px;
        }

        .input-group-text {
            background-color: var(--highlight-color);
            color: var(--light-color);
            border: none;
            border-radius: 50px;
        }

        /* Badges */
        .badge-success {
            background-color: #28a745;
        }

        .badge-warning {
            background-color: #ffc107;
            color: #212529;
        }

        .badge-secondary {
            background-color: #6c757d;
        }

        /* Checkbox Styling */
        .form-check-input:checked {
            background-color: var(--highlight-color);
            border-color: var(--highlight-color);
        }

        /* Buttons */
        .btn-lg {
            padding: 15px 30px;
            font-size: 1.2em;
            border-radius: 50px;
        }

        /* Tabelle */
        .table thead th {
            background-color: var(--secondary-color);
            color: var(--light-color);
        }

        .table-striped tbody tr:nth-of-type(odd) {
            background-color: #f8f9fa;
        }

        .table-responsive {
            margin-bottom: 30px;
        }
    </style>
</head>
<body>

<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png" alt="Logo"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-2"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-2"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-2"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-2"></i>Berichte
             </a>
         </li>
         <?php if ($moduleInstalled): ?>
             <li class="nav-item">
                 <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
                     <i class="bi bi-box me-2"></i>Artikel
                 </a>
             </li>
         <?php endif; ?>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill me-2"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-2"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>


<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <?php if ($moduleInstalled): ?>
        <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'MODUL/index.php') ? 'active' : ''; ?>" href="MODUL/">
            <i class="bi bi-box"></i>
            Artikel
        </a>
    <?php endif; ?>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="container inventur-container">
    <h2><i class="bi bi-box-seam me-2"></i>Kapazität aktualisieren</h2>

    <!-- Fortschrittsbalken -->
    <div class="progress">
        <div class="progress-bar" role="progressbar" style="width: <?php echo isset($progressPercentage) ? $progressPercentage : 0; ?>%;" aria-valuenow="<?php echo isset($progressPercentage) ? $progressPercentage : 0; ?>" aria-valuemin="0" aria-valuemax="100">
            <?php echo isset($progressPercentage) ? $progressPercentage : 0; ?>%
        </div>
    </div>

    <!-- Erfolgsmeldung -->
    <?php if (!empty($message)): ?>
        <div class="alert alert-success text-center" role="alert">
            <i class="bi bi-check-circle-fill me-2"></i><?php echo htmlspecialchars($message); ?>
        </div>
    <?php endif; ?>

    <!-- Fehlermeldungen -->
    <?php if (!empty($errors)): ?>
        <div class="alert alert-danger text-center" role="alert">
            <i class="bi bi-exclamation-triangle-fill me-2"></i>
            <?php foreach ($errors as $error): ?>
                <p><?php echo htmlspecialchars($error); ?></p>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>

    <?php if ($show_ebenen_auswahl): ?>
        <!-- Auswahlseite für Ebenen -->
        <div class="ebenen-auswahl">
            <h3><i class="bi bi-filter-square me-2"></i>Bereiche auswählen</h3>
            <form method="POST" action="kapazitaet.php">
                <div class="mb-4">
                    <div class="form-check">
                        <input class="form-check-input" type="checkbox" value="Alles" id="ebeneAlles" name="ebenen[]" checked>
                        <label class="form-check-label" for="ebeneAlles">Alles</label>
                    </div>
                    <?php if (!empty($verfuegbare_ebenen)): ?>
                        <?php foreach ($verfuegbare_ebenen as $ebene): ?>
                            <div class="form-check">
                                <input 
                                    class="form-check-input" 
                                    type="checkbox" 
                                    value="<?php echo htmlspecialchars(strtoupper($ebene['kurzel'])); ?>" 
                                    id="ebene<?php echo htmlspecialchars($ebene['kurzel']); ?>" 
                                    name="ebenen[]" 
                                    checked>
                                <label class="form-check-label" for="ebene<?php echo htmlspecialchars($ebene['kurzel']); ?>">
                                    <?php echo htmlspecialchars($ebene['bezeichnung']); ?>
                                </label>
                            </div>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <p class="text-muted">Keine Ebenen verfügbar. Bitte konfigurieren Sie die Ebenen in den Einstellungen.</p>
                    <?php endif; ?>
                </div>
                <button type="submit" name="action" value="start" class="btn btn-primary btn-lg"><i class="bi bi-play-circle-fill me-2"></i>Starten</button>
            </form>
        </div>

        <!-- JavaScript für verbesserte Ebenenauswahl -->
        <script>
            document.addEventListener('DOMContentLoaded', function () {
                const allesCheckbox = document.getElementById('ebeneAlles');
                const ebenenCheckboxes = <?php echo json_encode($verfuegbare_ebenen); ?>.map(function(ebene) {
                    return document.getElementById('ebene' + ebene.kurzel);
                });

                allesCheckbox.addEventListener('change', function () {
                    const isChecked = this.checked;
                    ebenenCheckboxes.forEach(function (checkbox) {
                        checkbox.checked = isChecked;
                        checkbox.disabled = isChecked; // Deaktiviert die einzelnen Checkboxen, wenn "Alles" ausgewählt ist
                    });
                });

                ebenenCheckboxes.forEach(function (checkbox) {
                    checkbox.addEventListener('change', function () {
                        if (!this.checked) {
                            allesCheckbox.checked = false;
                            ebenenCheckboxes.forEach(function (cb) {
                                cb.disabled = false; // Aktiviert Checkboxen, wenn "Alles" nicht mehr ausgewählt ist
                            });
                        } else {
                            const allChecked = ebenenCheckboxes.every(function (cb) {
                                return cb.checked;
                            });
                            if (allChecked) {
                                allesCheckbox.checked = true;
                                ebenenCheckboxes.forEach(function (cb) {
                                    cb.disabled = true;
                                });
                            }
                        }
                    });
                });
            });
        </script>
    <?php elseif ($progressExists && !$show_ebenen_auswahl): ?>
        <?php if (!$currentLagerplatz && empty($message)): ?>
            <!-- Zusammenfassungsseite -->
            <div class="inventur-summary">
                <h3 class="mb-4"><i class="bi bi-list-check me-2"></i>Zusammenfassung</h3>
                <div class="table-responsive">
                    <table class="table table-striped table-bordered">
                        <thead>
                            <tr>
                                <th>Lagerplatz</th>
                                <th>Alte Kapazität</th>
                                <th>Neue Kapazität</th>
                                <th>Status</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            // Hole alle Einträge
                            $stmt = $pdo->prepare('
                                SELECT lp.name, lp.kapazitaet AS alt, kp.kapazitaet AS neu, kp.completed
                                FROM lagerplaetze lp
                                JOIN kapazitaet_progress kp ON lp.id = kp.lagerplatz_id
                                WHERE kp.mitarbeiter_id = ?
                            ');
                            $stmt->execute([$mitarbeiter_id]);
                            $kapazitaetData = $stmt->fetchAll(PDO::FETCH_ASSOC);

                            foreach ($kapazitaetData as $data):
                                // Ebene erkennen (optional, falls benötigt)
                                // $ebene = strtoupper($data['ebene']); // Da wir die Ebene direkt aus der Tabelle haben

                                if ($data['completed'] == 1) {
                                    $status = '<span class="badge badge-success">Abgeschlossen</span>';
                                    $neueKap = $data['neu'];
                                } elseif ($data['completed'] == 2) {
                                    $status = '<span class="badge badge-warning text-dark">Übersprungen</span>';
                                    $neueKap = $data['alt']; // Alte Kapazität beibehalten
                                } else {
                                    $status = '<span class="badge badge-secondary">Offen</span>';
                                    $neueKap = $data['alt']; // Noch nicht bearbeitet, alte Kapazität beibehalten
                                }
                            ?>
                            <tr>
                                <td><?php echo htmlspecialchars($data['name']); ?></td>
                                <td><?php echo htmlspecialchars($data['alt']); ?></td>
                                <td><?php echo htmlspecialchars($neueKap); ?></td>
                                <td><?php echo $status; ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <form method="POST" action="kapazitaet.php">
                    <button type="submit" name="action" value="updateDatabase" class="btn btn-success btn-lg mt-3">
                        <i class="bi bi-save2 me-2"></i>Aktualisierung abschließen
                    </button>
                </form>
            </div>
        <?php else: ?>
            <!-- Eingabeseite für den aktuellen Lagerplatz -->
            <div class="inventur-entry">
                <h3 class="mb-3"><i class="bi bi-warehouse me-2"></i>Lagerplatz: <?php echo htmlspecialchars($currentLagerplatz['name']); ?></h3>
                <p class="current-capacity"><i class="bi bi-boxes me-2"></i>Aktuelle Kapazität: <?php echo htmlspecialchars($currentLagerplatz['kapazitaet']); ?></p>
                <form method="POST" action="kapazitaet.php">
                    <input type="hidden" name="lagerplatz_id" value="<?php echo htmlspecialchars($currentLagerplatz['lagerplatz_id']); ?>">
                    <div class="input-group mb-4">
                        <span class="input-group-text"><i class="bi bi-pencil-fill"></i></span>
                        <input type="number" name="kapazitaet" class="form-control" placeholder="Neue Kapazität eingeben" autofocus required>
                    </div>
                    <div class="d-flex justify-content-between flex-wrap">
                        <button type="submit" name="action" value="zurueck" formnovalidate class="btn btn-warning btn-action mb-2">
                            <i class="bi bi-arrow-left-circle me-2"></i>Zurück
                        </button>
                        <button type="submit" name="action" value="ueberspringen" formnovalidate class="btn btn-secondary btn-action mb-2">
                            <i class="bi bi-arrow-right-circle me-2"></i>Überspringen
                        </button>
                        <button type="submit" name="action" value="weiter" class="btn btn-primary btn-action mb-2">
                            <i class="bi bi-check-circle me-2"></i>Weiter
                        </button>
                    </div>
                    <div class="mt-3">
                        <button type="submit" name="action" value="abbrechen" formnovalidate class="btn btn-danger btn-lg">
                            <i class="bi bi-x-circle me-2"></i>Aktualisierung abbrechen
                        </button>
                    </div>
                </form>
            </div>
        <?php endif; ?>
    <?php endif; ?>
</div>

<!-- Bootstrap JS und Abhängigkeiten -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<!-- JavaScript zur Initialisierung der Tooltips und zur Behandlung der Enter-Taste -->
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Tooltips initialisieren
        var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
        tooltipTriggerList.map(function (tooltipTriggerEl) {
            return new bootstrap.Tooltip(tooltipTriggerEl);
        });

        // Enter-Taste zum Weiter-Button zuordnen (nur in der Eingabeseite)
        const kapazitaetInput = document.querySelector('input[name="kapazitaet"]');
        const weiterButton = document.querySelector('button[name="action"][value="weiter"]');

        if (kapazitaetInput && weiterButton) {
            kapazitaetInput.addEventListener('keypress', function(event) {
                if (event.key === 'Enter') {
                    event.preventDefault();  // Verhindert das Standardformularverhalten
                    weiterButton.click();     // Klick auf den "Weiter"-Button simulieren
                }
            });
        }
    });
</script>

</body>
</html>
