<?php
include 'db_connect.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Eingaben trimmen und validieren
    $name = trim($_POST['name']);
    $benutzername = trim($_POST['benutzername']);
    $email = trim($_POST['email']);
    $passwort = trim($_POST['passwort']);
    $rolle = $_POST['rolle'] ?? 'Mitarbeiter';
    
    // Fehler-Array initialisieren
    $errors = [];

    // Grundlegende Validierung
    if (empty($name)) {
        $errors[] = "Name ist erforderlich.";
    }

    if (empty($benutzername)) {
        $errors[] = "Benutzername ist erforderlich.";
    }

    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = "Ungültige E-Mail-Adresse.";
    }

    if (strlen($passwort) < 6) {
        $errors[] = "Passwort muss mindestens 6 Zeichen lang sein.";
    }

    // Überprüfen, ob Benutzername bereits existiert
    if (empty($errors)) {
        $stmt = $pdo->prepare('SELECT * FROM mitarbeiter WHERE benutzername = ?');
        $stmt->execute([$benutzername]);
        if ($stmt->rowCount() > 0) {
            $errors[] = "Benutzername ist bereits vergeben.";
        }
    }

    // Benutzer registrieren, wenn keine Fehler vorhanden sind
    if (empty($errors)) {
        $hashedPasswort = password_hash($passwort, PASSWORD_DEFAULT);
        $stmt = $pdo->prepare('INSERT INTO mitarbeiter (name, benutzername, email, passwort, rolle) VALUES (?, ?, ?, ?, ?)');
        if ($stmt->execute([$name, $benutzername, $email, $hashedPasswort, $rolle])) {
            header('Location: login.php');
            exit();
        } else {
            $errors[] = "Registrierung fehlgeschlagen. Bitte versuchen Sie es erneut.";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Registrieren - PDP</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap" rel="stylesheet">
    <!-- Eigenes CSS -->
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            background: linear-gradient(135deg, #1e3c72 0%, #2a5298 100%);
            height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
            transition: background 0.5s;
        }

        .registration-container {
            background-color: #ffffff;
            padding: 40px;
            border-radius: 15px;
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
            max-width: 500px;
            width: 100%;
            animation: fadeInUp 0.6s ease-out;
        }

        .registration-container h2 {
            margin-bottom: 30px;
            color: #2a5298;
            text-align: center;
            font-weight: 700;
        }

        .form-control:focus {
            border-color: #2a5298;
            box-shadow: none;
        }

        .btn-primary {
            background-color: #2a5298;
            border-color: #2a5298;
            transition: background-color 0.3s, transform 0.3s;
        }

        .btn-primary:hover {
            background-color: #1e3c72;
            transform: translateY(-2px);
        }

        .alert {
            border-radius: 10px;
            animation: fadeIn 0.5s ease-in-out;
        }

        .mobile-nav {
            display: none;
        }

        @media (max-width: 767.98px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #ffffff;
                box-shadow: 0 -2px 5px rgba(0,0,0,0.1);
                justify-content: space-around;
                padding: 10px 0;
                z-index: 1000;
                transition: background-color 0.5s;
            }
            .mobile-nav a {
                color: #6c757d;
                text-decoration: none;
                font-size: 0.8em;
                text-align: center;
                flex: 1;
                transition: color 0.3s;
            }
            .mobile-nav a i {
                font-size: 1.4rem;
                margin-bottom: 3px;
            }
            .mobile-nav a.active {
                color: #2a5298;
            }
            .mobile-nav a:hover {
                color: #2a5298;
            }
        }

        @keyframes fadeInUp {
            from {
                opacity: 0;
                transform: translateY(20px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        @keyframes fadeIn {
            from { opacity: 0; }
            to { opacity: 1; }
        }
    </style>
</head>
<body>

    <div class="registration-container">
        <h2><i class="bi bi-person-plus-fill me-2"></i>Registrieren</h2>
        
        <?php if (!empty($errors)): ?>
            <div class="alert alert-danger">
                <ul class="mb-0">
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo htmlspecialchars($error); ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>

        <form action="register.php" method="POST" novalidate>
            <div class="mb-3">
                <label for="name" class="form-label"><i class="bi bi-person-fill me-1"></i>Name</label>
                <input type="text" class="form-control" id="name" name="name" value="<?php echo isset($name) ? htmlspecialchars($name) : ''; ?>" required>
                <div class="invalid-feedback">
                    Bitte geben Sie Ihren Namen ein.
                </div>
            </div>
            <div class="mb-3">
                <label for="benutzername" class="form-label"><i class="bi bi-person-circle me-1"></i>Benutzername</label>
                <input type="text" class="form-control" id="benutzername" name="benutzername" value="<?php echo isset($benutzername) ? htmlspecialchars($benutzername) : ''; ?>" required>
                <div class="invalid-feedback">
                    Bitte wählen Sie einen Benutzernamen.
                </div>
            </div>
            <div class="mb-3">
                <label for="email" class="form-label"><i class="bi bi-envelope-fill me-1"></i>E-Mail</label>
                <input type="email" class="form-control" id="email" name="email" value="<?php echo isset($email) ? htmlspecialchars($email) : ''; ?>" required>
                <div class="invalid-feedback">
                    Bitte geben Sie eine gültige E-Mail-Adresse ein.
                </div>
            </div>
            <div class="mb-3">
                <label for="passwort" class="form-label"><i class="bi bi-lock-fill me-1"></i>Passwort</label>
                <input type="password" class="form-control" id="passwort" name="passwort" required>
                <div class="invalid-feedback">
                    Bitte wählen Sie ein sicheres Passwort.
                </div>
            </div>
            <div class="mb-4">
                <label for="rolle" class="form-label"><i class="bi bi-person-check-fill me-1"></i>Rolle</label>
                <select class="form-select" id="rolle" name="rolle">
                    <option value="Mitarbeiter" <?php echo (isset($rolle) && $rolle == 'Mitarbeiter') ? 'selected' : ''; ?>>Mitarbeiter</option>
                   <!-- <option value="Admin" <?php echo (isset($rolle) && $rolle == 'Admin') ? 'selected' : ''; ?>>Admin</option> -->
                </select>
            </div>
            <button type="submit" class="btn btn-primary w-100"><i class="bi bi-check-circle-fill me-2"></i>Registrieren</button>
        </form>
        <p class="mt-3 text-center">Bereits registriert? <a href="login.php" class="text-primary"><i class="bi bi-box-arrow-in-right me-1"></i>Hier anmelden</a>.</p>
    </div>

    <!-- Mobile Bottom Navigation -->
    <div class="mobile-nav d-md-none">
        <a href="dashboard.php">
            <i class="bi bi-speedometer2"></i>
            Dashboard
        </a>
        <a href="aufgaben.php">
            <i class="bi bi-list-task"></i>
            Aufgaben
        </a>
        <a href="lagerplaetze.php">
            <i class="bi bi-box-seam"></i>
            Lagerplätze
        </a>
        <a href="berichte.php">
            <i class="bi bi-bar-chart-fill"></i>
            Berichte
        </a>
        <a href="logout.php">
            <i class="bi bi-box-arrow-right"></i>
            Abmelden
        </a>
    </div>

    <!-- Bootstrap JS und Validation -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Bootstrap-Formularvalidierung
        (function () {
            'use strict'
            var forms = document.querySelectorAll('form')
            Array.prototype.slice.call(forms)
                .forEach(function (form) {
                    form.addEventListener('submit', function (event) {
                        if (!form.checkValidity()) {
                            event.preventDefault()
                            event.stopPropagation()
                        }
                        form.classList.add('was-validated')
                    }, false)
                })
        })()
    </script>
</body>
</html>
